(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    295199,       6162]
NotebookOptionsPosition[    252592,       5173]
NotebookOutlinePosition[    289796,       5984]
CellTagsIndexPosition[    289753,       5981]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["The SinSurface application example", "Title"],

Cell["\<\
Copyright \[Copyright] MathCore AB 1999-2004\
\>", "Copyright"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
 "Below we describe the SinSurface program example. The actual computation is \
performed by the functions ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 ", ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " and their help functions."
}], "Text",
 CellChangeTimes->{{3.508677896284031*^9, 3.5086778966590242`*^9}}],

Cell[TextData[{
 "The two functions ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 " and ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " in the SinSurface package will be translated to C++ together with the \
declaration of the global array ",
 StyleBox["xyMatrix",
  FontFamily->"Courier"],
 "."
}], "Text"],

Cell[TextData[{
 "The array ",
 StyleBox["xyMatrix",
  FontFamily->"Courier"],
 " represents a 21x21 grid on which which the numeric function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " will be computed."
}], "Text"],

Cell[TextData[{
 "The function ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 " accepts four arguments which are coordinates that describe a square in the \
x-y plane, and one counter (",
 StyleBox["iter",
  FontFamily->"Courier"],
 ") to make the function repeat the computation as many times as necessary \
for measuring execution time. For each point on a 21x21 grid in that square, \
the numeric function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " is called to compute a value that is stored as a matrix element in the \
matrix representing the grid."
}], "Text"],

Cell[TextData[{
 "The function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " computes essentially the same values as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["Sin",
     FontFamily->"Courier"], "(", 
    RowBox[{"x", "+", "y"}], ")"}], TraditionalForm]]],
 ", but in a more complicated way using a rather large expression obtained \
through conversion of the arguments into polar coordinates (through ",
 StyleBox["arcTan",
  FontFamily->"Courier"],
 ") and then using series expansion of both ",
 StyleBox["Sin",
  FontFamily->"Courier"],
 " and ",
 StyleBox["Cos",
  FontFamily->"Courier"],
 " in 10 terms. The resulting large symbolic expression (more than a page) \
becomes the body of ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 ", and is then used as input to ",
 StyleBox["CompileEvaluateFunction",
  FontFamily->"Courier"],
 " (see Section 7.5 and Section 7.6.3 in the manual) to generate efficient \
C++ code."
}], "Text"],

Cell[TextData[{
 "The SinSurface example application computes a function (here ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 ") over a 2-D grid. The function values are first stored in the matrix ",
 StyleBox["xyMatrix",
  FontFamily->"Courier"],
 " before being plotted. The execution of compiled C++ code for the function \
",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " is approximately 500-1000 times faster than evaluating the same function \
interpretively within Mathematica."
}], "Text",
 CellChangeTimes->{{3.5086710318823495`*^9, 3.5086710329917107`*^9}}],

Cell["\<\
To run this example, evaluate this notebook cell by cell or the whole at \
once.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell["Load the MathCode package", "Subsection"],

Cell["\<\
First put a Needs statement, to make sure that the MathCode application is \
loaded:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MathCode`\>\"", "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"MathCode C++ 1.4.4\"\>", "\[InvisibleSpace]", "\<\" for \"\>", 
   "\[InvisibleSpace]", "\<\"vc100\"\>", 
   "\[InvisibleSpace]", "\<\" loaded from \"\>", 
   "\[InvisibleSpace]", "\<\"C:\\\\b\\\\omath\\\\MathCode\"\>"}],
  SequenceForm[
  "MathCode C++ 1.4.4", " for ", "vc100", " loaded from ", 
   "C:\\b\\omath\\MathCode"],
  Editable->False]], "Print",
 CellChangeTimes->{3.508677838019525*^9}]
}, Open  ]],

Cell["Define a time measurement function called AbsTime:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetAttributes", "[", 
    RowBox[{"AbsTime", ",", "HoldFirst"}], "]"}], ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AbsTime", "[", "xt_", "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "\n", "  ", 
      RowBox[{"start", ",", "res"}], "\n", " ", "}"}], ",", "\n", "   ", 
     RowBox[{
      RowBox[{"start", " ", "=", " ", 
       RowBox[{"AbsoluteTime", "[", "]"}]}], ";", "\n", "   ", 
      RowBox[{"res", "=", "xt"}], ";", "\n", "   ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"AbsoluteTime", "[", "]"}], "-", "start"}], ")"}], " ", ",",
         "res"}], "}"}]}]}], "\n", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.391423788984679*^9, {3.3914240677021685`*^9, 3.3914240690928116`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check current directory", "Subsection"],

Cell["\<\
You might want to set the directory to some place where all generated files \
are put, e.g. the one below, or some other directory.\
\>", "Text"],

Cell["\<\
SetDirectory[$MCRoot<>$PathnameSeparator<>\"Demos\"<>$PathnameSeparator<>\"\
SinSurface\"];\
\>", "Input"],

Cell["Check whether this file is in the current directory.", "Text"],

Cell["ExistFileQ[\"SinSurface.nb\"]", "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Start of the SinSurface package", "Section"],

Cell["\<\
The SinSurface package starts in the usual way by a BeginPackage declaration \
which references other packages.The MathCodeContexts are needed in order to \
call the code generation related functions. \
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BeginPackage", "[", 
    RowBox[{"\"\<SinSurface`\>\"", ",", " ", 
     RowBox[{"{", "MathCodeContexts", "}"}]}], "]"}], ";"}], " "}], "\n", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", "\"\<SinSurface`*\>\"", "]"}], ";"}], 
  " "}]}], "Input"],

Cell[CellGroupData[{

Cell["Exported symbols", "Subsection"],

Cell[TextData[{
 "Define possibly exported symbols. Even though it is not necessary here, we \
enclose these names within a ",
 StyleBox["Begin[\"SinSurface\[OpenCurlyQuote]\"] ... End[]",
  FontFamily->"Courier"],
 " kind of \[OpenCurlyDoubleQuote]context bracket\[CloseCurlyDoubleQuote], \
since this can be put into a cell in the notebook, and conveniently \
re-evaluated (only this cell!) when a new name is added to the list below."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<SinSurface`\>\"", "]"}], ";"}], "\n", 
 RowBox[{" ", 
  RowBox[{"xyMatrix", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"calcPlot", ";"}]}], "\n", 
 RowBox[{" ", 
  RowBox[{"sinFun1", ";"}]}], "\n", 
 RowBox[{" ", 
  RowBox[{"sinFun2", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"arcTan", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"sin", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"cos", ";"}]}], "\n", 
 RowBox[{" ", 
  RowBox[{"plot", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"cplus", ";"}], " "}], "\n", 
 RowBox[{" ", 
  RowBox[{"plotfile", ";"}]}], "\n", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setting compilation options", "Subsection"],

Cell[TextData[{
 "This defines how the functions and variables in the package should be \
compiled to C++. By default, all typed variables and functions are compiled. \
However, the compilation process can be controlled in a more detailed manner \
by setting compilation options via ",
 StyleBox["SetCompilationOptions",
  FontFamily->"Courier"],
 ". For example, in this package the function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " should be symbolically evaluated before being translated to code since it \
contains symbolic operations; the functions ",
 StyleBox["sin",
  FontFamily->"Courier"],
 ", ",
 StyleBox["cos",
  FontFamily->"Courier"],
 ", and ",
 StyleBox["arcTan",
  FontFamily->"Courier"],
 " should not be compiled at all since they are expanded within the body of \
",
 StyleBox["sinFun2.",
  FontFamily->"Courier"],
 " The remaining typed function, ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 ", will be compiled in the normal way."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetCompilationOptions", "[", "\n", "  ", 
   RowBox[{
    RowBox[{"EvaluateFunctions", "->", 
     RowBox[{"{", "sinFun2", "}"}]}], ",", "\n", "  ", 
    RowBox[{"UnCompiledFunctions", "->", 
     RowBox[{"{", 
      RowBox[{"sin", ",", "cos", ",", "arcTan"}], "}"}]}], ",", "\n", "  ", 
    RowBox[{"MainFileAndFunction", "->", "\"\<int main(){return 0;}\>\""}]}], 
   "\n", "]"}], ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The body of the SinSurface package", "Section"],

Cell["\<\
Begin the implementation section of the SinSurface package, where functions \
are defined. This is usually private, to avoid accidental name shadowing due \
to identical local variables in several packages.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Begin", "[", "\"\<SinSurface`Private`\>\"", "]"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Global variables", "Subsection"],

Cell["Declare global variables.", "Text"],

Cell[TextData[{
 StyleBox["\nDeclare",
  FontColor->RGBColor[0, 0, 1]],
 "[\n  ",
 StyleBox["Real[21,21]",
  FontColor->RGBColor[0, 0, 1]],
 "  xyMatrix \n];\n"
}], "Input",
 CellChangeTimes->{{3.5086773005610943`*^9, 3.508677310045287*^9}, {
  3.5086776184768653`*^9, 3.508677620836195*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["sin, cos", "Subsection"],

Cell["Taylor-expanded sin and cos functions.", "Text"],

Cell["\<\
sin[Real x_ ] -> Real := Normal[Series[Sin[z], {z,0,10}]] /. z -> x ;
cos[Real x_ ] -> Real := Normal[Series[Cos[z], {z,0,10}]] /. z -> x ;\
\>", "Input",
 CellChangeTimes->{
  3.508670914821348*^9, {3.508674226260747*^9, 3.508674227463849*^9}, {
   3.5086776253829827`*^9, 3.508677626195467*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["arcTan", "Subsection"],

Cell[TextData[{
 "Conversion of grid point to an angle, called by ",
 StyleBox["sinFun2.",
  FontFamily->"Courier"]
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"arcTan", "[", 
     RowBox[{
      RowBox[{"Real", " ", "x_"}], ",", 
      RowBox[{"Real", " ", "y_"}]}], "]"}], "\[Rule]", "Real"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "<", "0"}], ",", "Pi", ",", "0"}], "]"}], 
     "\[IndentingNewLine]", "+", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"Sign", "[", "y", "]"}], "*", 
        RowBox[{"Pi", "/", "2"}]}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"y", "/", "x"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5086706487935033`*^9, 3.5086706786524963`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["sinFun2", "Subsection"],

Cell[TextData[{
 "The function ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " is the function to be computed and plotted, called by ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 ". It provides a more complicated and computationally heavier way (series \
expansion) to calculate approximately the same as ",
 StyleBox["Sin[x+y]",
  FontFamily->"Courier"],
 ". This gives an example of a combination of symbolic and numeric operations \
as well as a rather standard mix of arithmetic operations. The expanded \
symbolic expression which comprises the body of ",
 StyleBox["SinFun2",
  FontFamily->"Courier"],
 " is between 1 and 2 pages long when printed."
}], "Text"],

Cell[TextData[{
 "Note that the types of local variables to ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " need not necessarily be declared since ",
 StyleBox["CompileEvaluateFunction",
  FontFamily->"Courier"],
 " will symbolically expand the whole body before translating it to C++ code. \
"
}], "Text"],

Cell["\<\
Note also that a function to be symbolically expanded before final code \
generation should be without side effects, e.g. assignment to global \
variables or input/output, since otherwise these actions will be performed \
during the symbolic evaluation, which would be problematic.\
\>", "Text"],

Cell["\<\
sinFun2[Real x_,Real y_] -> Real := Block[
   {
   \tReal {r,xx,yy}
   },
    r = Sqrt[x^2+y^2];
    xx =  r*cos[arcTan[x,y]];
    yy = r*sin[arcTan[x,y]]; 
    sin[xx+yy]
  ];\
\>", "Input",
 CellChangeTimes->{3.5086707091833553`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["calcPlot ", "Subsection"],

Cell[TextData[{
 "The function ",
 StyleBox["calcPlot",
  FontFamily->"Courier"],
 " calculates data for a plot of sinFun2 over a 21x21 grid, which is returned \
as a 21x21 array."
}], "Text"],

Cell["\<\
calcPlot[Real xmin_, Real xmax_, Real ymin_,
 Real ymax_, Integer iter_] -> Real[_,_] := 
 Module[{  
    Integer  n = 20,
    Real {xc,yc}, 
    Integer {i, j, count}
   
 },
   For[count=1,count<=iter,count=count+1,
   \tFor[i=1, i<=(n+1),  i=i+1, 
      For[j=1, j<=(n+1), j=j+1,
\t    xc = xmin+(xmax-xmin)*(i-1)/n; 
\t    yc = ymin+(ymax-ymin)*(j-1)/n;
\t    xyMatrix[[i,j]] = sinFun2[xc,yc]
       ]
    ]
   ];
   xyMatrix
 ];\
\>", "Input",
 CellChangeTimes->{{3.3914241174215555`*^9, 3.391424132156119*^9}, 
   3.5086707268237543`*^9, {3.508673296324678*^9, 3.508673297199628*^9}, 
   3.5086734982817945`*^9, {3.5086773199044733`*^9, 3.508677321591941*^9}, {
   3.5086776125551043`*^9, 3.5086776148363104`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["End of the SinSurface package", "Subsection"],

Cell["\<\
End[];
EndPackage[]; \
\>", "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Execution", "Section"],

Cell[TextData[{
 "We first execute the application interpretively within ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", and then compile the key function and execute the application again. Then \
we compile the application to C++, build an executable, and call the same \
functions from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " via ",
 StyleBox["MathLink",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " evaluation"
}], "Subsection"],

Cell[TextData[{
 "Let ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " calculate a plot."
}], "Text"],

Cell[CellGroupData[{

Cell["meval = AbsTime[plot = calcPlot[-2., 2., -2., 2., 1] ][[1]]", "Input",
 CellChangeTimes->{3.391423850562016*^9}],

Cell[BoxData["0.2031211`6.75930003328482"], "Output",
 CellChangeTimes->{3.508677838441392*^9}]
}, Open  ]],

Cell["Perform the plot.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", "plot", "]"}]], "Input"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxtnXdcE2n3tyOKGxU1QJQAQRIIkV6SoGLjgA3sYlmxodi7goqoC7Fj712x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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmgf41tP7x5/nc86JSBRpIEW2SFSoSGWVEEKiNJCRbAlJCWWv7JmEMpKS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         "]], Polygon3DBox[CompressedData["
1:eJw1mgn8V8P3xu+dO5OlsiSVlDYikUqRLJEtoSwVQhtl+ZE9JJIk2ZWULNkT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         "]], Polygon3DBox[CompressedData["
1:eJwt1XlMl3UcB/CfgLd5oGDiAaZlm1ameRTeJ4EgoCAKCrbVOpa2jul0mpmG
F+KFeHX9UatZLrt02bV0WU07QAUVVNSCtvqj2mxtNno96/vHl8/zfn0/3+fh
9/y+z/Mb+NDS/CVxsViszGhrZPszMT4Wmw3btonFhiXEYg1Gb9aXvaMnUc7R
N5nlsY76hrPZbArLZ53YvawzK2albBArZblsGpvLurJRbCjbxfawcraXDWNV
bC/bwPaxWWwCy2EJbCi7k+1gu9mLrIoNYdtZFVvLdrE8Np0VsG5sNJvPVrLN
bAl7gg1mlWwnW822sSK2gm1iT7LHWRnbxPaF/289m8G6sH7hXv3ruAObry5k
qfqK9Q1ne9gBVsFeZQmskC1gKayQtWdFrIQNYAtYF1bCythgVsYeZEnsdnbM
dbuwRWwd2xU+x0p2D6tm+9kW9gqbybqxVHbY2jhWyJaxcvaovodZMVvNtrJn
2FOshK1h29gy9iwrZeWsOnwfa9hC9gLbzpaz59g8tpxtYI+xR9hiVsFeDvdl
E1vAVrEK9jRbyuJZAZvP+rAC1mrks0LWi+XK/fVtYFvC2nXsoPG9XCPf5fN+
Zv5GdA/V7LCvJsnTre3I+rA39f3t+DA/I9frGcNOsiPsArvEprAadpRdZJfZ
VFbLJjtfvNqTH2C/O57AWqP9aOxmzazF2jR1cPguB8p/RXuLZbJWli5/aNTJ
F11jHDtlfpLzxamJfD/7zfEgtlXdwVbprbRuHDsn/yJn6/vG/BWeog4I+6C3
3GykRudgn7A0eby15+Vfrc1np81PYx3UW/kb7Ibjf6LnVc0N74jpcrq+Wvma
nKHvuPkprK2axF9jfzi+Gb1P1DnhHZEpXzb6sP7sPX3J8iHjJ/msnhHsK/PX
WD81jX/E+spTXaMdS2avsz8dX4/2hzqQfcz6yceMRrnJ+WayOvP3Wfs1Oxeu
8S6r0XeL2iPc5zbyHH1ZrDg8v5PZXJbDFoVnfwa7n52WG+Xx1h41n8LWqxvD
++V5fWPZKbkhfL9Honcry1CLeFLk0V5hm1lleAY3skyWzrLCfrmDfWFcka/r
mcUaonehvjx1cXiXZOkZzb6Vz4c9/r75Mew7doGNZR+wL/U2sZ/DHmpkI/Qd
Z7Xh2XqLndB3nbWE/XKV9da3Vn0pvF9W6HmA/ShfCc/M5+Z/4J3UruH5uBn/
/w/VHHVeuAd5eiZGP16sO6t22BJ9djZOnRX9wOkbEj2TRnJ0v9lB3EOuN3pG
/1PYu53l48Y1uTk6P2syP8r5TrI6NpIdYp/qu8Suhv1cz86y7mqvsJ/bySOt
PSGf0Xc3e9t8BktUbwv7r72+/wApwdm4
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], 
      Line3DBox[{2, 1, 22, 935, 43, 956, 64, 977, 85, 106, 127, 998, 148, 
       1019, 169, 1040, 190, 211, 232, 1061, 253, 1082, 274, 1103, 295, 316, 
       337, 1124, 358, 1145, 379, 1166, 400, 421, 422, 682, 423, 683, 424, 
       684, 425, 426, 427, 685, 428, 686, 429, 687, 430, 431, 432, 688, 433, 
       689, 434, 690, 435, 436, 437, 691, 438, 692, 439, 693, 440, 441, 420, 
       1185, 399, 1164, 378, 1143, 357, 336, 315, 1122, 294, 1101, 273, 1080, 
       252, 231, 210, 1059, 189, 1038, 168, 1017, 147, 126, 105, 996, 84, 975,
        63, 954, 42, 21, 20, 464, 19, 462, 18, 460, 17, 16, 15, 458, 14, 456, 
       13, 454, 12, 11, 10, 452, 9, 450, 8, 448, 7, 6, 5, 446, 4, 444, 3, 442,
        2}]}, {Line3DBox[{935, 1186, 934, 706, 936, 1330, 1426, 937, 1331, 
       1427, 938, 1187, 939, 1188, 940, 709, 941, 1332, 1428, 942, 1333, 1429,
        943, 1189, 944, 1190, 945, 712, 946, 1334, 1430, 947, 1335, 1431, 948,
        1191, 949, 1192, 950, 715, 951, 1336, 1432, 952, 1337, 1433, 953, 
       1193, 954}], 
      Line3DBox[{956, 1194, 955, 1378, 1195, 957, 719, 958, 1338, 1434, 959, 
       1196, 960, 1197, 961, 1379, 1198, 962, 722, 963, 1339, 1435, 964, 1199,
        965, 1200, 966, 1380, 1201, 967, 725, 968, 1340, 1436, 969, 1202, 970,
        1203, 971, 1381, 1204, 972, 728, 973, 1341, 1437, 974, 1205, 975}], 
      Line3DBox[{977, 1206, 976, 1382, 1207, 978, 1383, 1208, 979, 732, 980, 
       1209, 981, 1210, 982, 1384, 1211, 983, 1385, 1212, 984, 735, 985, 1213,
        986, 1214, 987, 1386, 1215, 988, 1387, 1216, 989, 738, 990, 1217, 991,
        1218, 992, 1388, 1219, 993, 1389, 1220, 994, 741, 995, 1221, 996}], 
      Line3DBox[{106, 107, 502, 108, 503, 109, 504, 110, 111, 112, 505, 113, 
       506, 114, 507, 115, 116, 117, 508, 118, 509, 119, 510, 120, 121, 122, 
       511, 123, 512, 124, 513, 125, 126}], 
      Line3DBox[{998, 1222, 997, 766, 999, 1342, 1438, 1000, 1343, 1439, 1001,
        1223, 1002, 1224, 1003, 769, 1004, 1344, 1440, 1005, 1345, 1441, 1006,
        1225, 1007, 1226, 1008, 772, 1009, 1346, 1442, 1010, 1347, 1443, 1011,
        1227, 1012, 1228, 1013, 775, 1014, 1348, 1444, 1015, 1349, 1445, 1016,
        1229, 1017}], 
      Line3DBox[{1019, 1230, 1018, 1390, 1231, 1020, 779, 1021, 1350, 1446, 
       1022, 1232, 1023, 1233, 1024, 1391, 1234, 1025, 782, 1026, 1351, 1447, 
       1027, 1235, 1028, 1236, 1029, 1392, 1237, 1030, 785, 1031, 1352, 1448, 
       1032, 1238, 1033, 1239, 1034, 1393, 1240, 1035, 788, 1036, 1353, 1449, 
       1037, 1241, 1038}], 
      Line3DBox[{1040, 1242, 1039, 1394, 1243, 1041, 1395, 1244, 1042, 792, 
       1043, 1245, 1044, 1246, 1045, 1396, 1247, 1046, 1397, 1248, 1047, 795, 
       1048, 1249, 1049, 1250, 1050, 1398, 1251, 1051, 1399, 1252, 1052, 798, 
       1053, 1253, 1054, 1254, 1055, 1400, 1255, 1056, 1401, 1256, 1057, 801, 
       1058, 1257, 1059}], 
      Line3DBox[{211, 212, 562, 213, 563, 214, 564, 215, 216, 217, 565, 218, 
       566, 219, 567, 220, 221, 222, 568, 223, 569, 224, 570, 225, 226, 227, 
       571, 228, 572, 229, 573, 230, 231}], 
      Line3DBox[{1061, 1258, 1060, 826, 1062, 1354, 1450, 1063, 1355, 1451, 
       1064, 1259, 1065, 1260, 1066, 829, 1067, 1356, 1452, 1068, 1357, 1453, 
       1069, 1261, 1070, 1262, 1071, 832, 1072, 1358, 1454, 1073, 1359, 1455, 
       1074, 1263, 1075, 1264, 1076, 835, 1077, 1360, 1456, 1078, 1361, 1457, 
       1079, 1265, 1080}], 
      Line3DBox[{1082, 1266, 1081, 1402, 1267, 1083, 839, 1084, 1362, 1458, 
       1085, 1268, 1086, 1269, 1087, 1403, 1270, 1088, 842, 1089, 1363, 1459, 
       1090, 1271, 1091, 1272, 1092, 1404, 1273, 1093, 845, 1094, 1364, 1460, 
       1095, 1274, 1096, 1275, 1097, 1405, 1276, 1098, 848, 1099, 1365, 1461, 
       1100, 1277, 1101}], 
      Line3DBox[{1103, 1278, 1102, 1406, 1279, 1104, 1407, 1280, 1105, 852, 
       1106, 1281, 1107, 1282, 1108, 1408, 1283, 1109, 1409, 1284, 1110, 855, 
       1111, 1285, 1112, 1286, 1113, 1410, 1287, 1114, 1411, 1288, 1115, 858, 
       1116, 1289, 1117, 1290, 1118, 1412, 1291, 1119, 1413, 1292, 1120, 861, 
       1121, 1293, 1122}], 
      Line3DBox[{316, 317, 622, 318, 623, 319, 624, 320, 321, 322, 625, 323, 
       626, 324, 627, 325, 326, 327, 628, 328, 629, 329, 630, 330, 331, 332, 
       631, 333, 632, 334, 633, 335, 336}], 
      Line3DBox[{1124, 1294, 1123, 886, 1125, 1366, 1462, 1126, 1367, 1463, 
       1127, 1295, 1128, 1296, 1129, 889, 1130, 1368, 1464, 1131, 1369, 1465, 
       1132, 1297, 1133, 1298, 1134, 892, 1135, 1370, 1466, 1136, 1371, 1467, 
       1137, 1299, 1138, 1300, 1139, 895, 1140, 1372, 1468, 1141, 1373, 1469, 
       1142, 1301, 1143}], 
      Line3DBox[{1145, 1302, 1144, 1414, 1303, 1146, 899, 1147, 1374, 1470, 
       1148, 1304, 1149, 1305, 1150, 1415, 1306, 1151, 902, 1152, 1375, 1471, 
       1153, 1307, 1154, 1308, 1155, 1416, 1309, 1156, 905, 1157, 1376, 1472, 
       1158, 1310, 1159, 1311, 1160, 1417, 1312, 1161, 908, 1162, 1377, 1473, 
       1163, 1313, 1164}], 
      Line3DBox[{1166, 1314, 1165, 1418, 1315, 1167, 1419, 1316, 1168, 912, 
       1169, 1317, 1170, 1318, 1171, 1420, 1319, 1172, 1421, 1320, 1173, 915, 
       1174, 1321, 1175, 1322, 1176, 1422, 1323, 1177, 1423, 1324, 1178, 918, 
       1179, 1325, 1180, 1326, 1181, 1424, 1327, 1182, 1425, 1328, 1183, 921, 
       1184, 1329, 1185}]}, {
      Line3DBox[{442, 694, 443, 706, 466, 718, 1378, 478, 730, 1382, 490, 742,
        502, 754, 514, 766, 526, 778, 1390, 538, 790, 1394, 550, 802, 562, 
       814, 574, 826, 586, 838, 1402, 598, 850, 1406, 610, 862, 622, 874, 634,
        886, 646, 898, 1414, 658, 910, 1418, 670, 922, 682}], 
      Line3DBox[{444, 695, 445, 1426, 707, 467, 719, 479, 731, 1383, 491, 743,
        503, 755, 515, 1438, 767, 527, 779, 539, 791, 1395, 551, 803, 563, 
       815, 575, 1450, 827, 587, 839, 599, 851, 1407, 611, 863, 623, 875, 635,
        1462, 887, 647, 899, 659, 911, 1419, 671, 923, 683}], 
      Line3DBox[{446, 696, 447, 1427, 708, 468, 1434, 720, 480, 732, 492, 744,
        504, 756, 516, 1439, 768, 528, 1446, 780, 540, 792, 552, 804, 564, 
       816, 576, 1451, 828, 588, 1458, 840, 600, 852, 612, 864, 624, 876, 636,
        1463, 888, 648, 1470, 900, 660, 912, 672, 924, 684}], 
      Line3DBox[{6, 27, 939, 48, 960, 69, 981, 90, 111, 132, 1002, 153, 1023, 
       174, 1044, 195, 216, 237, 1065, 258, 1086, 279, 1107, 300, 321, 342, 
       1128, 363, 1149, 384, 1170, 405, 426}], 
      Line3DBox[{448, 697, 449, 709, 469, 721, 1379, 481, 733, 1384, 493, 745,
        505, 757, 517, 769, 529, 781, 1391, 541, 793, 1396, 553, 805, 565, 
       817, 577, 829, 589, 841, 1403, 601, 853, 1408, 613, 865, 625, 877, 637,
        889, 649, 901, 1415, 661, 913, 1420, 673, 925, 685}], 
      Line3DBox[{450, 698, 451, 1428, 710, 470, 722, 482, 734, 1385, 494, 746,
        506, 758, 518, 1440, 770, 530, 782, 542, 794, 1397, 554, 806, 566, 
       818, 578, 1452, 830, 590, 842, 602, 854, 1409, 614, 866, 626, 878, 638,
        1464, 890, 650, 902, 662, 914, 1421, 674, 926, 686}], 
      Line3DBox[{452, 699, 453, 1429, 711, 471, 1435, 723, 483, 735, 495, 747,
        507, 759, 519, 1441, 771, 531, 1447, 783, 543, 795, 555, 807, 567, 
       819, 579, 1453, 831, 591, 1459, 843, 603, 855, 615, 867, 627, 879, 639,
        1465, 891, 651, 1471, 903, 663, 915, 675, 927, 687}], 
      Line3DBox[{11, 32, 944, 53, 965, 74, 986, 95, 116, 137, 1007, 158, 1028,
        179, 1049, 200, 221, 242, 1070, 263, 1091, 284, 1112, 305, 326, 347, 
       1133, 368, 1154, 389, 1175, 410, 431}], 
      Line3DBox[{454, 700, 455, 712, 472, 724, 1380, 484, 736, 1386, 496, 748,
        508, 760, 520, 772, 532, 784, 1392, 544, 796, 1398, 556, 808, 568, 
       820, 580, 832, 592, 844, 1404, 604, 856, 1410, 616, 868, 628, 880, 640,
        892, 652, 904, 1416, 664, 916, 1422, 676, 928, 688}], 
      Line3DBox[{456, 701, 457, 1430, 713, 473, 725, 485, 737, 1387, 497, 749,
        509, 761, 521, 1442, 773, 533, 785, 545, 797, 1399, 557, 809, 569, 
       821, 581, 1454, 833, 593, 845, 605, 857, 1411, 617, 869, 629, 881, 641,
        1466, 893, 653, 905, 665, 917, 1423, 677, 929, 689}], 
      Line3DBox[{458, 702, 459, 1431, 714, 474, 1436, 726, 486, 738, 498, 750,
        510, 762, 522, 1443, 774, 534, 1448, 786, 546, 798, 558, 810, 570, 
       822, 582, 1455, 834, 594, 1460, 846, 606, 858, 618, 870, 630, 882, 642,
        1467, 894, 654, 1472, 906, 666, 918, 678, 930, 690}], 
      Line3DBox[{16, 37, 949, 58, 970, 79, 991, 100, 121, 142, 1012, 163, 
       1033, 184, 1054, 205, 226, 247, 1075, 268, 1096, 289, 1117, 310, 331, 
       352, 1138, 373, 1159, 394, 1180, 415, 436}], 
      Line3DBox[{460, 703, 461, 715, 475, 727, 1381, 487, 739, 1388, 499, 751,
        511, 763, 523, 775, 535, 787, 1393, 547, 799, 1400, 559, 811, 571, 
       823, 583, 835, 595, 847, 1405, 607, 859, 1412, 619, 871, 631, 883, 643,
        895, 655, 907, 1417, 667, 919, 1424, 679, 931, 691}], 
      Line3DBox[{462, 704, 463, 1432, 716, 476, 728, 488, 740, 1389, 500, 752,
        512, 764, 524, 1444, 776, 536, 788, 548, 800, 1401, 560, 812, 572, 
       824, 584, 1456, 836, 596, 848, 608, 860, 1413, 620, 872, 632, 884, 644,
        1468, 896, 656, 908, 668, 920, 1425, 680, 932, 692}], 
      Line3DBox[{464, 705, 465, 1433, 717, 477, 1437, 729, 489, 741, 501, 753,
        513, 765, 525, 1445, 777, 537, 1449, 789, 549, 801, 561, 813, 573, 
       825, 585, 1457, 837, 597, 1461, 849, 609, 861, 621, 873, 633, 885, 645,
        1469, 897, 657, 1473, 909, 669, 921, 681, 933, 693}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxUm3c8le8bx0UoW4XIiAZZZVT2rYysaNAwGmSviIwkqUgoRFkZZY/sPW6O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    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{1., 21.}, {1., 21.}, {-1.0000015077136721`, 
   0.9995779388049383}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.508677838503891*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " standard ",
 StyleBox["Compile[]",
  FontFamily->"Courier"]
}], "Subsection"],

Cell[TextData[{
 "Redefine ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " to become a compiled version, using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " standard ",
 StyleBox["Compile[]",
  FontFamily->"Courier"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"$VersionNumber", "\[GreaterEqual]", "8"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sinFun2", "=", 
      RowBox[{"Compile", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xt", ",", "yt"}], "}"}], ",", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"sinFun2", "[", 
          RowBox[{"xt", ",", "yt"}], "]"}], "]"}], ",", 
        RowBox[{"CompilationTarget", "\[Rule]", "\"\<MVM\>\""}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"compeval", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"AbsTime", "[", 
         RowBox[{
          RowBox[{"plot", "=", 
           RowBox[{"calcPlot", "[", 
            RowBox[{
             RowBox[{"-", "2."}], ",", "2.", ",", 
             RowBox[{"-", "2."}], ",", "2.", ",", "300"}], "]"}]}], ";"}], 
         "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "  ", "/", " ", "300"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sinFun2", "=."}], ";", "\[IndentingNewLine]", 
     RowBox[{"Compiler`$CCompilerOptions", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<CleanIntermediate\>\"", "\[Rule]", "False"}], ",", 
        RowBox[{"\"\<ShellCommandFunction\>\"", "\[Rule]", "Print"}]}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"sinFun2", "=", 
      RowBox[{"Compile", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xt", ",", "yt"}], "}"}], ",", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"sinFun2", "[", 
          RowBox[{"xt", ",", "yt"}], "]"}], "]"}], ",", 
        RowBox[{"CompilationTarget", "\[Rule]", "\"\<C\>\""}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"calc", "=", 
      RowBox[{"Compile", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"tms", ",", "_Integer"}], "}"}], "}"}], ",", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"calcPlot", "[", 
          RowBox[{
           RowBox[{"-", "2."}], ",", "2.", ",", 
           RowBox[{"-", "2."}], ",", "2.", ",", "tms"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"_", ",", "_Real", ",", "2"}], "}"}], "}"}], ",", 
        RowBox[{"CompilationTarget", "\[Rule]", "\"\<C\>\""}]}], "]"}]}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"fnames", "=", 
      RowBox[{"FileNames", "[", 
       RowBox[{"\"\<*.c\>\"", ",", 
        RowBox[{"FileNames", "[", 
         RowBox[{
          RowBox[{"FileNameDrop", "[", 
           RowBox[{
            RowBox[{"sinFun2", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "]"}], "]"}], ",", 
            RowBox[{"-", "1"}]}], "]"}], "<>", "\"\<\\\\W*\>\""}], "]"}]}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"FilePrint", "/@", " ", "fnames"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"compevalC", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"AbsTime", "[", 
         RowBox[{
          RowBox[{"plot", "=", 
           RowBox[{"calcPlot", "[", 
            RowBox[{
             RowBox[{"-", "2."}], ",", "2.", ",", 
             RowBox[{"-", "2."}], ",", "2.", ",", "300"}], "]"}]}], ";"}], 
         "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "/", " ", "300"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "calc", " ", "does", " ", "not", " ", "measure", " ", "it", " ", 
       "correctly"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"sinFun2", "=."}], ";"}], "\[IndentingNewLine]", ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"sinFun2", "=", 
      RowBox[{"Compile", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xt", ",", "yt"}], "}"}], ",", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"sinFun2", "[", 
          RowBox[{"xt", ",", "yt"}], "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"compeval", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"AbsTime", "[", 
         RowBox[{
          RowBox[{"plot", "=", 
           RowBox[{"calcPlot", "[", 
            RowBox[{
             RowBox[{"-", "2."}], ",", "2.", ",", 
             RowBox[{"-", "2."}], ",", "2.", ",", "300"}], "]"}]}], ";"}], 
         "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "/", " ", "300"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"compevalC", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
     RowBox[{"sinFun2", "=."}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.508671093803432*^9, 3.508671125521776*^9}, {
   3.5086712205049353`*^9, 3.5086712621919017`*^9}, 3.508671297066455*^9, {
   3.5086713305191517`*^9, 3.5086713877684193`*^9}, {3.5086715332040577`*^9, 
   3.5086715408914595`*^9}, {3.5086718414188623`*^9, 3.508671866465417*^9}, {
   3.508671914792923*^9, 3.5086719670578794`*^9}, {3.508672261562434*^9, 
   3.508672281986906*^9}, {3.508673036663412*^9, 3.5086730463654194`*^9}, {
   3.508673325901099*^9, 3.508673330166478*^9}, {3.508673486610592*^9, 
   3.508673534389141*^9}, {3.5086736143709564`*^9, 3.5086736151678057`*^9}, {
   3.508673799396285*^9, 3.5086738109271665`*^9}, {3.508673902737179*^9, 
   3.508673904830875*^9}, {3.508673937986276*^9, 3.5086739433298893`*^9}, {
   3.508673994672325*^9, 3.508674007875112*^9}, {3.508675745137834*^9, 
   3.5086757484346457`*^9}, {3.50867578521519*^9, 3.5086757997930346`*^9}, {
   3.5086758608231125`*^9, 3.50867598857066*^9}, {3.5086761010060015`*^9, 
   3.508676107427753*^9}, {3.5086767022288322`*^9, 3.5086767328688693`*^9}, 
   3.508676785758479*^9, {3.5086771255175805`*^9, 3.5086771343924103`*^9}, 
   3.5086776460857105`*^9, {3.508677810488804*^9, 3.508677823066687*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Boolean", "::", "shdw"}], "MessageName"], ":", 
  " ", "\<\"Symbol \[NoBreak]\\!\\(\\\"Boolean\\\"\\)\[NoBreak] appears in \
multiple contexts \[NoBreak]\\!\\({\\\"CompiledFunctionTools`\\\", \
\\\"MathCodeLanguage`\\\"}\\)\[NoBreak]; definitions in context \[NoBreak]\\!\
\\(\\\"CompiledFunctionTools`\\\"\\)\[NoBreak] may shadow or be shadowed by \
other definitions. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\
\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/shdw\\\", ButtonNote -> \
\\\"CompiledFunctionTools`Boolean::shdw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5086778422225695`*^9}],

Cell[BoxData["\<\"call \\\"C:\\\\Program\\\\Microsoft Visual Studio \
10.0\\\\VC\\\\vcvarsall.bat\\\" x86\\n\\n\\ncl.exe /LD /O2 /MT  /I \
\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\IncludeFiles\\\\C\\\" /I \
\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\Links\\\\MathLink\\\\\
DeveloperKit\\\\Windows\\\\CompilerAdditions\\\\mldev32\\\\include\\\" \\\"C:\
\\\\Documents and Settings\\\\vaden\\\\Application \
Data\\\\Mathematica\\\\ApplicationData\\\\CCompilerDriver\\\\BuildFolder\\\\\
helenus-3308\\\\Working-helenus-3308-5412-1\\\\compiledFunction0.c\\\" /link  \
/implib:\\\"C:\\\\Documents and Settings\\\\vaden\\\\Application \
Data\\\\Mathematica\\\\ApplicationData\\\\CCompilerDriver\\\\BuildFolder\\\\\
helenus-3308\\\\Working-helenus-3308-5412-1\\\\compiledFunction0.lib\\\"  \
/LIBPATH:\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\Links\\\\MathLink\\\\\
DeveloperKit\\\\Windows\\\\CompilerAdditions\\\\mldev32\\\\lib\\\" \
/LIBPATH:\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\Libraries\\\\Windows\\\"  \\\
\"ml32i3m.lib\\\"  /out:\\\"C:\\\\Documents and \
Settings\\\\vaden\\\\Application \
Data\\\\Mathematica\\\\ApplicationData\\\\CCompilerDriver\\\\BuildFolder\\\\\
helenus-3308\\\\Working-helenus-3308-5412-1\\\\compiledFunction0.dll\\\"\\n\\\
n\"\>"], "Print",
 CellChangeTimes->{3.5086778425819373`*^9}],

Cell[BoxData["\<\"call \\\"C:\\\\Program\\\\Microsoft Visual Studio \
10.0\\\\VC\\\\vcvarsall.bat\\\" x86\\n\\n\\ncl.exe /LD /O2 /MT  /I \
\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\IncludeFiles\\\\C\\\" /I \
\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\Links\\\\MathLink\\\\\
DeveloperKit\\\\Windows\\\\CompilerAdditions\\\\mldev32\\\\include\\\" \\\"C:\
\\\\Documents and Settings\\\\vaden\\\\Application \
Data\\\\Mathematica\\\\ApplicationData\\\\CCompilerDriver\\\\BuildFolder\\\\\
helenus-3308\\\\Working-helenus-3308-5412-2\\\\compiledFunction1.c\\\" /link  \
/implib:\\\"C:\\\\Documents and Settings\\\\vaden\\\\Application \
Data\\\\Mathematica\\\\ApplicationData\\\\CCompilerDriver\\\\BuildFolder\\\\\
helenus-3308\\\\Working-helenus-3308-5412-2\\\\compiledFunction1.lib\\\"  \
/LIBPATH:\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\Links\\\\MathLink\\\\\
DeveloperKit\\\\Windows\\\\CompilerAdditions\\\\mldev32\\\\lib\\\" \
/LIBPATH:\\\"c:\\\\Program\\\\Wolfram \
Research\\\\Mathematica\\\\8.0\\\\SystemFiles\\\\Libraries\\\\Windows\\\"  \\\
\"ml32i3m.lib\\\"  /out:\\\"C:\\\\Documents and \
Settings\\\\vaden\\\\Application \
Data\\\\Mathematica\\\\ApplicationData\\\\CCompilerDriver\\\\BuildFolder\\\\\
helenus-3308\\\\Working-helenus-3308-5412-2\\\\compiledFunction1.dll\\\"\\n\\\
n\"\>"], "Print",
 CellChangeTimes->{3.508677843441296*^9}]
}, Open  ]],

Cell["sinFun2 =. ", "Input",
 CellChangeTimes->{{3.508673457784127*^9, 3.5086734647212276`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fully Expanded Symbolic expression to be compiled to C++", "Subsection"],

Cell[TextData[{
 "This shows the size of ",
 StyleBox["sinFun2",
  FontFamily->"Courier"],
 " fully expanded. Be prepared for a big output."
}], "Text"],

Cell[CellGroupData[{

Cell["sinFun2[a, b]", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"a", "\[Equal]", "0"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
       RowBox[{"ArcTan", "[", 
        FractionBox["b", "a"], "]"}]}], "]"}], "+", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}], "-", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "3"]}], "+", 
     RowBox[{
      FractionBox["1", "120"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "5"]}], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "7"], "5040"], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "9"], "362880"]}], ")"}]}], "+", 
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "2"]}], "+", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "4"]}], "-", 
     RowBox[{
      FractionBox["1", "720"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "6"]}], "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "8"], "40320"], "-", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], ")"}], 
       "10"], "3628800"]}], ")"}]}], "-", 
  RowBox[{
   FractionBox["1", "6"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}], "-", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "3"]}], "+", 
         RowBox[{
          FractionBox["1", "120"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "5"]}], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "7"], "5040"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "9"], "362880"]}], ")"}]}], "+", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "2"]}], "+", 
         RowBox[{
          FractionBox["1", "24"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "4"]}], "-", 
         RowBox[{
          FractionBox["1", "720"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "6"]}], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "8"], "40320"], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "10"], "3628800"]}], ")"}]}]}], ")"}], "3"]}], "+", 
  RowBox[{
   FractionBox["1", "120"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}], "-", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "3"]}], "+", 
         RowBox[{
          FractionBox["1", "120"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "5"]}], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "7"], "5040"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "9"], "362880"]}], ")"}]}], "+", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "2"]}], "+", 
         RowBox[{
          FractionBox["1", "24"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "4"]}], "-", 
         RowBox[{
          FractionBox["1", "720"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "6"]}], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "8"], "40320"], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "10"], "3628800"]}], ")"}]}]}], ")"}], "5"]}], "-", 
  RowBox[{
   FractionBox["1", "5040"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}], "-", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "3"]}], "+", 
         RowBox[{
          FractionBox["1", "120"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "5"]}], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "7"], "5040"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "9"], "362880"]}], ")"}]}], "+", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "2"]}], "+", 
         RowBox[{
          FractionBox["1", "24"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "4"]}], "-", 
         RowBox[{
          FractionBox["1", "720"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "6"]}], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "8"], "40320"], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "10"], "3628800"]}], ")"}]}]}], ")"}], "7"]}], "+", 
  RowBox[{
   FractionBox["1", "362880"], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "\[Equal]", "0"}], ",", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
           RowBox[{"ArcTan", "[", 
            FractionBox["b", "a"], "]"}]}], "]"}], "+", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}], "-", 
         RowBox[{
          FractionBox["1", "6"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "3"]}], "+", 
         RowBox[{
          FractionBox["1", "120"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "5"]}], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "7"], "5040"], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "9"], "362880"]}], ")"}]}], "+", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "2"]}], "+", 
         RowBox[{
          FractionBox["1", "24"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "4"]}], "-", 
         RowBox[{
          FractionBox["1", "720"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "6"]}], "+", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "8"], "40320"], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "\[Equal]", "0"}], ",", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"Sign", "[", "b", "]"}], " ", "\[Pi]"}], ",", 
               RowBox[{"ArcTan", "[", 
                FractionBox["b", "a"], "]"}]}], "]"}], "+", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"a", "<", "0"}], ",", "\[Pi]", ",", "0"}], "]"}]}], 
            ")"}], "10"], "3628800"]}], ")"}]}]}], ")"}], "9"]}]}]], "Output",\

 CellChangeTimes->{3.508677847456844*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the MathCode code generator", "Subsection"],

Cell["Compile the SinSurface package:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompilePackage", "[", "\"\<SinSurface\>\"", "]"}]], "Input"],

Cell[BoxData["\<\"Successful compilation to C++: 2 function(s)\"\>"], "Print",
 CellChangeTimes->{3.5086778500817933`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The generated C++ code", "Subsection"],

Cell[TextData[{
 "Below follows the generated C++ code from the SinSurface program. Notice \
that the package name becomes a prefix of the name of the generated C++ \
function. Thus the Mathematica function ",
 StyleBox["SinSurface\[OpenCurlyQuote]sinFun2",
  FontFamily->"Courier"],
 " becomes ",
 StyleBox["SinSurface_TsinFun2",
  FontFamily->"Courier"],
 " in C++."
}], "Text"],

Cell[TextData[{
 "The generated code from ",
 StyleBox["SinSurface\[OpenCurlyQuote]sinFun2",
  FontFamily->"Courier"],
 " is produced from a large expression by ",
 StyleBox["CompileEvaluateFunction",
  FontFamily->"Courier"],
 ". Common subexpression elimination is performed by the code generator, \
producing many temporary variables and subexpressions which can be seen in \
the body of the C++ function ",
 StyleBox["SinSurface_TsinFun2.",
  FontFamily->"Courier"]
}], "Text"],

Cell[TextData[{
 "By contrast, the C++ code in the body of function ",
 StyleBox["SinSurface_TcalcPlot",
  FontFamily->"Courier"],
 " produced by ",
 StyleBox["CompileFunction",
  FontFamily->"Courier"],
 " from the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["SinSurface\[OpenCurlyQuote]calcPlot",
  FontFamily->"Courier"],
 ", follows the structure of the original code quite closely."
}], "Text"],

Cell["\<\
We give a command to type out the text of the generated C++ file:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FilePrint", "[", "\"\<SinSurface.cc\>\"", "]"}]], "Input"],

Cell["\<\
#include \"SinSurface.h\"

#include \"SinSurface.icc\"

#include <math.h>
doubleNN SinSurface_TcalcPlot ( const double &xmin, const double &xmax, const \

    double &ymin, const double &ymax, const int &iter)
{
    int n = 20;
    double xc;
    double yc;
    int i;
    int j;
    int count;
    count = 1;
    while (count <= iter)
    {
        i = 1;
        while (i <= n+1)
        {
            j = 1;
            while (j <= n+1)
            {
                xc = xmin+((xmax+-xmin)*(i+-1))/n;
                yc = ymin+((ymax+-ymin)*(j+-1))/n;
                SinSurface_TxyMatrix(i, j) = SinSurface_TsinFun2 (xc, yc);
                j = j+1;
            }
            i = i+1;
        }
        count = count+1;
    }
    return SinSurface_TxyMatrix;
}

void SinSurface_TSinSurfaceInit ()
{
; 
}

double SinSurface_TsinFun2 ( const double &x, const double &y)
{
    int mc_T1;
    double mc_T2;
    double mc_T3;
    double mc_T4;
    int mc_T5;
    double mc_T6;
    double mc_T7;
    int mc_T8;
    double mc_T9;
    double mc_T10;
    double mc_T11;
    double mc_T12;
    double mc_T13;
    double mc_T14;
    double mc_T15;
    double mc_T16;
    double mc_T17;
    double mc_T18;
    double mc_T19;
    double mc_T20;
    double mc_T21;
    double mc_T22;
    double mc_T23;
    double mc_T24;
    double mc_T25;
    double mc_T26;
    double mc_T27;
    double mc_T28;
    double mc_T29;
    double mc_T30;
    double mc_T31;
    double mc_T32;
    double mc_T33;
    double mc_T34;
    double mc_T35;
    double mc_T36;
    double mc_T37;
    double mc_T38;
    double mc_T39;
    double mc_T40;
    double mc_T41;
    double mc_T42;
    double mc_T43;
    double mc_T44;
    double mc_T45;
    double mc_T46;
    double mc_T47;
    double mc_T48;
    double mc_T49;
    double mc_T50;
    double mc_T51;
    double mc_T52;
    mc_T1 = x < 0;
    if (mc_T1)
    {
        mc_T2 = 3.14159265358979323846;
    }
    else
    {
        mc_T2 = 0;
    }
    mc_T3 = y/x;
    mc_T4 = atan(mc_T3);
    mc_T5 = sign (y);
    mc_T6 = 3.14159265358979323846*mc_T5;
    mc_T7 = mc_T6/2;
    mc_T8 = x == 0;
    if (mc_T8)
    {
        mc_T9 = mc_T7;
    }
    else
    {
        mc_T9 = mc_T4;
    }
    mc_T10 = mc_T9+mc_T2;
    mc_T11 = pow(mc_T10, 10);
    mc_T12 =    -2.755731922398589e-007;
    mc_T13 = mc_T12*mc_T11;
    mc_T14 = pow(mc_T10, 8);
    mc_T15 = mc_T14/40320;
    mc_T16 = pow(mc_T10, 6);
    mc_T17 =      -0.001388888888888889;
    mc_T18 = mc_T17*mc_T16;
    mc_T19 = (mc_T10*mc_T10*mc_T10*mc_T10);
    mc_T20 = mc_T19/24;
    mc_T21 = (mc_T10*mc_T10);
    mc_T22 =                       -0.5;
    mc_T23 = mc_T22*mc_T21;
    mc_T24 = 1+mc_T23+mc_T20+mc_T18+mc_T15+mc_T13;
    mc_T25 =                        0.5;
    mc_T26 = (y*y);
    mc_T27 = (x*x);
    mc_T28 = mc_T27+mc_T26;
    mc_T29 = pow(mc_T28, mc_T25);
    mc_T30 = mc_T29*mc_T24;
    mc_T31 = pow(mc_T10, 9);
    mc_T32 = mc_T31/362880;
    mc_T33 = pow(mc_T10, 7);
    mc_T34 =     -0.0001984126984126984;
    mc_T35 = mc_T34*mc_T33;
    mc_T36 = pow(mc_T10, 5);
    mc_T37 = mc_T36/120;
    mc_T38 = (mc_T10*mc_T10*mc_T10);
    mc_T39 =        -0.1666666666666667;
    mc_T40 = mc_T39*mc_T38;
    mc_T41 = mc_T9+mc_T2+mc_T40+mc_T37+mc_T35+mc_T32;
    mc_T42 = mc_T29*mc_T41;
    mc_T43 = mc_T42+mc_T30;
    mc_T44 = pow(mc_T43, 9);
    mc_T45 = mc_T44/362880;
    mc_T46 = pow(mc_T43, 7);
    mc_T47 = mc_T34*mc_T46;
    mc_T48 = pow(mc_T43, 5);
    mc_T49 = mc_T48/120;
    mc_T50 = (mc_T43*mc_T43*mc_T43);
    mc_T51 = mc_T39*mc_T50;
    mc_T52 = mc_T42+mc_T30+mc_T51+mc_T49+mc_T47+mc_T45;
    return mc_T52;
}

doubleNN SinSurface_TxyMatrix(21, 21);\
\>", "Print",
 CellChangeTimes->{3.508677850175542*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compiling and linking the C++ code", "Subsection"],

Cell[TextData[{
 "The command ",
 StyleBox["MakeBinary",
  FontFamily->"Courier"],
 " compiles the generated C++ code using some C++ compiler (in this \
particular case the MicroSoft Visual C++, version 5.0, for WindowsNT). The \
object code is by default linked into  executable ",
 StyleBox["SinSurfaceml.exe",
  FontFamily->"Courier"],
 " for calling the compiled code via ",
 StyleBox["MathLink",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeBinary", "[", "]"}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installing and connecting to Mathematica", "Subsection"],

Cell[TextData[{
 "The command ",
 StyleBox["InstallCode",
  FontFamily->"Courier"],
 " installs and connects the external process containing the compiled and \
linked SinSurface code."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"installedLink", "=", 
  RowBox[{"InstallCode", "[", "\"\<SinSurface\>\"", "]"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SinSurface\"\>", 
   "\[InvisibleSpace]", "\<\" is installed.\"\>"}],
  SequenceForm["SinSurface", " is installed."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5086778538317213`*^9}],

Cell[BoxData[
 RowBox[{"LinkObject", "[", 
  RowBox[{"\<\"\\\"C:\\\\b\\\\omath\\\\MathCode\\\\Demos\\\\SinSurface\\\\\
SinSurfaceml.exe\\\"\"\>", ",", "15", ",", "8"}], "]"}]], "Output",
 CellChangeTimes->{3.5086778538317213`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Execution of generated C++ code", "Subsection"],

Cell["Perform the computation and the plot:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"externaleval", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"AbsTime", "[", 
     RowBox[{
      RowBox[{"plot", "=", 
       RowBox[{"calcPlot", "[", 
        RowBox[{
         RowBox[{"-", "2.0"}], ",", "2.0", ",", 
         RowBox[{"-", "2.0"}], ",", "2.0", ",", "3000"}], "]"}]}], ";"}], 
     "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/", "3000"}]}]], "Input"],

Cell[BoxData["0.00025520343333333333332264952`7.335552761006496"], "Output",
 CellChangeTimes->{3.508677854612956*^9}]
}, Open  ]],

Cell["Just check that we get the right result", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", "plot", "]"}]], "Input"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxtnXdcU9n2tyMKEzVqgCgBAiQQepEU7MrCCvY+YsPeC4oF1AEcu1hRrKjY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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmgf41tP7x5/nc86JSBRpIEW2SFSoSGWVEEKiNJCRbAlJCWWv7JmEMpKS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         "]], Polygon3DBox[CompressedData["
1:eJw1mgn8V8P3xu+dO5OlsiSVlDYikUqRLJEtoSwVQhtl+ZE9JJIk2ZWULNkT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         "]], Polygon3DBox[CompressedData["
1:eJwt1XlMl3UcB/CfgLd5oGDiAaZlm1ameRTeJ4EgoCAKCrbVOpa2jul0mpmG
F+KFeHX9UatZLrt02bV0WU07QAUVVNSCtvqj2mxtNno96/vHl8/zfn0/3+fh
9/y+z/Mb+NDS/CVxsViszGhrZPszMT4Wmw3btonFhiXEYg1Gb9aXvaMnUc7R
N5nlsY76hrPZbArLZ53YvawzK2albBArZblsGpvLurJRbCjbxfawcraXDWNV
bC/bwPaxWWwCy2EJbCi7k+1gu9mLrIoNYdtZFVvLdrE8Np0VsG5sNJvPVrLN
bAl7gg1mlWwnW822sSK2gm1iT7LHWRnbxPaF/289m8G6sH7hXv3ruAObry5k
qfqK9Q1ne9gBVsFeZQmskC1gKayQtWdFrIQNYAtYF1bCythgVsYeZEnsdnbM
dbuwRWwd2xU+x0p2D6tm+9kW9gqbybqxVHbY2jhWyJaxcvaovodZMVvNtrJn
2FOshK1h29gy9iwrZeWsOnwfa9hC9gLbzpaz59g8tpxtYI+xR9hiVsFeDvdl
E1vAVrEK9jRbyuJZAZvP+rAC1mrks0LWi+XK/fVtYFvC2nXsoPG9XCPf5fN+
Zv5GdA/V7LCvJsnTre3I+rA39f3t+DA/I9frGcNOsiPsArvEprAadpRdZJfZ
VFbLJjtfvNqTH2C/O57AWqP9aOxmzazF2jR1cPguB8p/RXuLZbJWli5/aNTJ
F11jHDtlfpLzxamJfD/7zfEgtlXdwVbprbRuHDsn/yJn6/vG/BWeog4I+6C3
3GykRudgn7A0eby15+Vfrc1np81PYx3UW/kb7Ibjf6LnVc0N74jpcrq+Wvma
nKHvuPkprK2axF9jfzi+Gb1P1DnhHZEpXzb6sP7sPX3J8iHjJ/msnhHsK/PX
WD81jX/E+spTXaMdS2avsz8dX4/2hzqQfcz6yceMRrnJ+WayOvP3Wfs1Oxeu
8S6r0XeL2iPc5zbyHH1ZrDg8v5PZXJbDFoVnfwa7n52WG+Xx1h41n8LWqxvD
++V5fWPZKbkhfL9Honcry1CLeFLk0V5hm1lleAY3skyWzrLCfrmDfWFcka/r
mcUaonehvjx1cXiXZOkZzb6Vz4c9/r75Mew7doGNZR+wL/U2sZ/DHmpkI/Qd
Z7Xh2XqLndB3nbWE/XKV9da3Vn0pvF9W6HmA/ShfCc/M5+Z/4J3UruH5uBn/
/w/VHHVeuAd5eiZGP16sO6t22BJ9djZOnRX9wOkbEj2TRnJ0v9lB3EOuN3pG
/1PYu53l48Y1uTk6P2syP8r5TrI6NpIdYp/qu8Suhv1cz86y7mqvsJ/bySOt
PSGf0Xc3e9t8BktUbwv7r72+/wApwdm4
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], 
      Line3DBox[{2, 1, 22, 935, 43, 956, 64, 977, 85, 106, 127, 998, 148, 
       1019, 169, 1040, 190, 211, 232, 1061, 253, 1082, 274, 1103, 295, 316, 
       337, 1124, 358, 1145, 379, 1166, 400, 421, 422, 682, 423, 683, 424, 
       684, 425, 426, 427, 685, 428, 686, 429, 687, 430, 431, 432, 688, 433, 
       689, 434, 690, 435, 436, 437, 691, 438, 692, 439, 693, 440, 441, 420, 
       1185, 399, 1164, 378, 1143, 357, 336, 315, 1122, 294, 1101, 273, 1080, 
       252, 231, 210, 1059, 189, 1038, 168, 1017, 147, 126, 105, 996, 84, 975,
        63, 954, 42, 21, 20, 464, 19, 462, 18, 460, 17, 16, 15, 458, 14, 456, 
       13, 454, 12, 11, 10, 452, 9, 450, 8, 448, 7, 6, 5, 446, 4, 444, 3, 442,
        2}]}, {Line3DBox[{935, 1186, 934, 706, 936, 1330, 1426, 937, 1331, 
       1427, 938, 1187, 939, 1188, 940, 709, 941, 1332, 1428, 942, 1333, 1429,
        943, 1189, 944, 1190, 945, 712, 946, 1334, 1430, 947, 1335, 1431, 948,
        1191, 949, 1192, 950, 715, 951, 1336, 1432, 952, 1337, 1433, 953, 
       1193, 954}], 
      Line3DBox[{956, 1194, 955, 1378, 1195, 957, 719, 958, 1338, 1434, 959, 
       1196, 960, 1197, 961, 1379, 1198, 962, 722, 963, 1339, 1435, 964, 1199,
        965, 1200, 966, 1380, 1201, 967, 725, 968, 1340, 1436, 969, 1202, 970,
        1203, 971, 1381, 1204, 972, 728, 973, 1341, 1437, 974, 1205, 975}], 
      Line3DBox[{977, 1206, 976, 1382, 1207, 978, 1383, 1208, 979, 732, 980, 
       1209, 981, 1210, 982, 1384, 1211, 983, 1385, 1212, 984, 735, 985, 1213,
        986, 1214, 987, 1386, 1215, 988, 1387, 1216, 989, 738, 990, 1217, 991,
        1218, 992, 1388, 1219, 993, 1389, 1220, 994, 741, 995, 1221, 996}], 
      Line3DBox[{106, 107, 502, 108, 503, 109, 504, 110, 111, 112, 505, 113, 
       506, 114, 507, 115, 116, 117, 508, 118, 509, 119, 510, 120, 121, 122, 
       511, 123, 512, 124, 513, 125, 126}], 
      Line3DBox[{998, 1222, 997, 766, 999, 1342, 1438, 1000, 1343, 1439, 1001,
        1223, 1002, 1224, 1003, 769, 1004, 1344, 1440, 1005, 1345, 1441, 1006,
        1225, 1007, 1226, 1008, 772, 1009, 1346, 1442, 1010, 1347, 1443, 1011,
        1227, 1012, 1228, 1013, 775, 1014, 1348, 1444, 1015, 1349, 1445, 1016,
        1229, 1017}], 
      Line3DBox[{1019, 1230, 1018, 1390, 1231, 1020, 779, 1021, 1350, 1446, 
       1022, 1232, 1023, 1233, 1024, 1391, 1234, 1025, 782, 1026, 1351, 1447, 
       1027, 1235, 1028, 1236, 1029, 1392, 1237, 1030, 785, 1031, 1352, 1448, 
       1032, 1238, 1033, 1239, 1034, 1393, 1240, 1035, 788, 1036, 1353, 1449, 
       1037, 1241, 1038}], 
      Line3DBox[{1040, 1242, 1039, 1394, 1243, 1041, 1395, 1244, 1042, 792, 
       1043, 1245, 1044, 1246, 1045, 1396, 1247, 1046, 1397, 1248, 1047, 795, 
       1048, 1249, 1049, 1250, 1050, 1398, 1251, 1051, 1399, 1252, 1052, 798, 
       1053, 1253, 1054, 1254, 1055, 1400, 1255, 1056, 1401, 1256, 1057, 801, 
       1058, 1257, 1059}], 
      Line3DBox[{211, 212, 562, 213, 563, 214, 564, 215, 216, 217, 565, 218, 
       566, 219, 567, 220, 221, 222, 568, 223, 569, 224, 570, 225, 226, 227, 
       571, 228, 572, 229, 573, 230, 231}], 
      Line3DBox[{1061, 1258, 1060, 826, 1062, 1354, 1450, 1063, 1355, 1451, 
       1064, 1259, 1065, 1260, 1066, 829, 1067, 1356, 1452, 1068, 1357, 1453, 
       1069, 1261, 1070, 1262, 1071, 832, 1072, 1358, 1454, 1073, 1359, 1455, 
       1074, 1263, 1075, 1264, 1076, 835, 1077, 1360, 1456, 1078, 1361, 1457, 
       1079, 1265, 1080}], 
      Line3DBox[{1082, 1266, 1081, 1402, 1267, 1083, 839, 1084, 1362, 1458, 
       1085, 1268, 1086, 1269, 1087, 1403, 1270, 1088, 842, 1089, 1363, 1459, 
       1090, 1271, 1091, 1272, 1092, 1404, 1273, 1093, 845, 1094, 1364, 1460, 
       1095, 1274, 1096, 1275, 1097, 1405, 1276, 1098, 848, 1099, 1365, 1461, 
       1100, 1277, 1101}], 
      Line3DBox[{1103, 1278, 1102, 1406, 1279, 1104, 1407, 1280, 1105, 852, 
       1106, 1281, 1107, 1282, 1108, 1408, 1283, 1109, 1409, 1284, 1110, 855, 
       1111, 1285, 1112, 1286, 1113, 1410, 1287, 1114, 1411, 1288, 1115, 858, 
       1116, 1289, 1117, 1290, 1118, 1412, 1291, 1119, 1413, 1292, 1120, 861, 
       1121, 1293, 1122}], 
      Line3DBox[{316, 317, 622, 318, 623, 319, 624, 320, 321, 322, 625, 323, 
       626, 324, 627, 325, 326, 327, 628, 328, 629, 329, 630, 330, 331, 332, 
       631, 333, 632, 334, 633, 335, 336}], 
      Line3DBox[{1124, 1294, 1123, 886, 1125, 1366, 1462, 1126, 1367, 1463, 
       1127, 1295, 1128, 1296, 1129, 889, 1130, 1368, 1464, 1131, 1369, 1465, 
       1132, 1297, 1133, 1298, 1134, 892, 1135, 1370, 1466, 1136, 1371, 1467, 
       1137, 1299, 1138, 1300, 1139, 895, 1140, 1372, 1468, 1141, 1373, 1469, 
       1142, 1301, 1143}], 
      Line3DBox[{1145, 1302, 1144, 1414, 1303, 1146, 899, 1147, 1374, 1470, 
       1148, 1304, 1149, 1305, 1150, 1415, 1306, 1151, 902, 1152, 1375, 1471, 
       1153, 1307, 1154, 1308, 1155, 1416, 1309, 1156, 905, 1157, 1376, 1472, 
       1158, 1310, 1159, 1311, 1160, 1417, 1312, 1161, 908, 1162, 1377, 1473, 
       1163, 1313, 1164}], 
      Line3DBox[{1166, 1314, 1165, 1418, 1315, 1167, 1419, 1316, 1168, 912, 
       1169, 1317, 1170, 1318, 1171, 1420, 1319, 1172, 1421, 1320, 1173, 915, 
       1174, 1321, 1175, 1322, 1176, 1422, 1323, 1177, 1423, 1324, 1178, 918, 
       1179, 1325, 1180, 1326, 1181, 1424, 1327, 1182, 1425, 1328, 1183, 921, 
       1184, 1329, 1185}]}, {
      Line3DBox[{442, 694, 443, 706, 466, 718, 1378, 478, 730, 1382, 490, 742,
        502, 754, 514, 766, 526, 778, 1390, 538, 790, 1394, 550, 802, 562, 
       814, 574, 826, 586, 838, 1402, 598, 850, 1406, 610, 862, 622, 874, 634,
        886, 646, 898, 1414, 658, 910, 1418, 670, 922, 682}], 
      Line3DBox[{444, 695, 445, 1426, 707, 467, 719, 479, 731, 1383, 491, 743,
        503, 755, 515, 1438, 767, 527, 779, 539, 791, 1395, 551, 803, 563, 
       815, 575, 1450, 827, 587, 839, 599, 851, 1407, 611, 863, 623, 875, 635,
        1462, 887, 647, 899, 659, 911, 1419, 671, 923, 683}], 
      Line3DBox[{446, 696, 447, 1427, 708, 468, 1434, 720, 480, 732, 492, 744,
        504, 756, 516, 1439, 768, 528, 1446, 780, 540, 792, 552, 804, 564, 
       816, 576, 1451, 828, 588, 1458, 840, 600, 852, 612, 864, 624, 876, 636,
        1463, 888, 648, 1470, 900, 660, 912, 672, 924, 684}], 
      Line3DBox[{6, 27, 939, 48, 960, 69, 981, 90, 111, 132, 1002, 153, 1023, 
       174, 1044, 195, 216, 237, 1065, 258, 1086, 279, 1107, 300, 321, 342, 
       1128, 363, 1149, 384, 1170, 405, 426}], 
      Line3DBox[{448, 697, 449, 709, 469, 721, 1379, 481, 733, 1384, 493, 745,
        505, 757, 517, 769, 529, 781, 1391, 541, 793, 1396, 553, 805, 565, 
       817, 577, 829, 589, 841, 1403, 601, 853, 1408, 613, 865, 625, 877, 637,
        889, 649, 901, 1415, 661, 913, 1420, 673, 925, 685}], 
      Line3DBox[{450, 698, 451, 1428, 710, 470, 722, 482, 734, 1385, 494, 746,
        506, 758, 518, 1440, 770, 530, 782, 542, 794, 1397, 554, 806, 566, 
       818, 578, 1452, 830, 590, 842, 602, 854, 1409, 614, 866, 626, 878, 638,
        1464, 890, 650, 902, 662, 914, 1421, 674, 926, 686}], 
      Line3DBox[{452, 699, 453, 1429, 711, 471, 1435, 723, 483, 735, 495, 747,
        507, 759, 519, 1441, 771, 531, 1447, 783, 543, 795, 555, 807, 567, 
       819, 579, 1453, 831, 591, 1459, 843, 603, 855, 615, 867, 627, 879, 639,
        1465, 891, 651, 1471, 903, 663, 915, 675, 927, 687}], 
      Line3DBox[{11, 32, 944, 53, 965, 74, 986, 95, 116, 137, 1007, 158, 1028,
        179, 1049, 200, 221, 242, 1070, 263, 1091, 284, 1112, 305, 326, 347, 
       1133, 368, 1154, 389, 1175, 410, 431}], 
      Line3DBox[{454, 700, 455, 712, 472, 724, 1380, 484, 736, 1386, 496, 748,
        508, 760, 520, 772, 532, 784, 1392, 544, 796, 1398, 556, 808, 568, 
       820, 580, 832, 592, 844, 1404, 604, 856, 1410, 616, 868, 628, 880, 640,
        892, 652, 904, 1416, 664, 916, 1422, 676, 928, 688}], 
      Line3DBox[{456, 701, 457, 1430, 713, 473, 725, 485, 737, 1387, 497, 749,
        509, 761, 521, 1442, 773, 533, 785, 545, 797, 1399, 557, 809, 569, 
       821, 581, 1454, 833, 593, 845, 605, 857, 1411, 617, 869, 629, 881, 641,
        1466, 893, 653, 905, 665, 917, 1423, 677, 929, 689}], 
      Line3DBox[{458, 702, 459, 1431, 714, 474, 1436, 726, 486, 738, 498, 750,
        510, 762, 522, 1443, 774, 534, 1448, 786, 546, 798, 558, 810, 570, 
       822, 582, 1455, 834, 594, 1460, 846, 606, 858, 618, 870, 630, 882, 642,
        1467, 894, 654, 1472, 906, 666, 918, 678, 930, 690}], 
      Line3DBox[{16, 37, 949, 58, 970, 79, 991, 100, 121, 142, 1012, 163, 
       1033, 184, 1054, 205, 226, 247, 1075, 268, 1096, 289, 1117, 310, 331, 
       352, 1138, 373, 1159, 394, 1180, 415, 436}], 
      Line3DBox[{460, 703, 461, 715, 475, 727, 1381, 487, 739, 1388, 499, 751,
        511, 763, 523, 775, 535, 787, 1393, 547, 799, 1400, 559, 811, 571, 
       823, 583, 835, 595, 847, 1405, 607, 859, 1412, 619, 871, 631, 883, 643,
        895, 655, 907, 1417, 667, 919, 1424, 679, 931, 691}], 
      Line3DBox[{462, 704, 463, 1432, 716, 476, 728, 488, 740, 1389, 500, 752,
        512, 764, 524, 1444, 776, 536, 788, 548, 800, 1401, 560, 812, 572, 
       824, 584, 1456, 836, 596, 848, 608, 860, 1413, 620, 872, 632, 884, 644,
        1468, 896, 656, 908, 668, 920, 1425, 680, 932, 692}], 
      Line3DBox[{464, 705, 465, 1433, 717, 477, 1437, 729, 489, 741, 501, 753,
        513, 765, 525, 1445, 777, 537, 1449, 789, 549, 801, 561, 813, 573, 
       825, 585, 1457, 837, 597, 1461, 849, 609, 861, 621, 873, 633, 885, 645,
        1469, 897, 657, 1473, 909, 669, 921, 681, 933, 693}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxcm3c8lu/bx8nMViES0TBTaNinrJBRSEUahBAiQkkayAyRWche2TtO43bf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    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{1., 21.}, {1., 21.}, {-1.0000015077136721`, 
   0.9995779388049381}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.50867785465983*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Performance Comparison", "Subsection"],

Cell[TextData[{
 "The performance between the three forms of execution are compared in the \
table below. The generated C++ code for this example is roughly 200-1000 \
times faster than standard interpreted ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code, and almost 50-100 times faster than expression code compiled by the \
internal ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["Compile[]",
  FontFamily->"Courier"],
 " command."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"meval", ",", 
       RowBox[{"meval", "/", "externaleval"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"compeval", ",", 
       RowBox[{"compeval", "/", "externaleval"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"compevalC", ",", 
       RowBox[{"compevalC", "/", "externaleval"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"externaleval", ",", "1"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TableHeadings", "->", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<Standard Mathematica\>\"", ",", "\"\<Compile[WVM]\>\"", ",", 
        "\"\<Compile[C]\>\"", ",", "\"\<External C++ via MathLink\>\""}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"\"\<Time consumed\>\"", ",", "\"\<Relative\>\""}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5086714586268873`*^9, 3.5086715215167074`*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"Time consumed\"\>",
       HoldForm], 
      TagBox["\<\"Relative\"\>",
       HoldForm]},
     {
      TagBox["\<\"Standard Mathematica\"\>",
       HoldForm], "0.2031211`6.75930003328482", 
      "795.9183673469387755969`6.657104423815078"},
     {
      TagBox["\<\"Compile[WVM]\"\>",
       HoldForm], "0.01166644266666666666682362213`7.995604699312144", 
      "45.7142857142857142882`7.249638132299903"},
     {
      TagBox["\<\"Compile[C]\"\>",
       HoldForm], "0.01062479599999999999992029292`7.95498684840388", 
      "41.6326530612244897974`7.242062407256576"},
     {
      TagBox["\<\"External C++ via MathLink\"\>",
       HoldForm], "0.00025520343333333333332264952`7.335552761006496", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "Standard Mathematica", "Compile[WVM]", "Compile[C]", 
       "External C++ via MathLink"}, {
      "Time consumed", "Relative"}}]]]], "Output",
 CellChangeTimes->{3.50867785469108*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[OutputFormData["\<\
TableForm[{{0.1874952`6.7245351474786625, \
734.6938775510204081719`6.629401392496409}, 
   {0.01124971200000000000004691387`7.979807652581967, \
44.0816326530612244924`7.246757858673671}, 
   {0.01052056399999999999995854243`7.950705270877664, \
41.2244897959183673491`7.2412276294251345}, 
   {0.00025520179999999999998575491`7.3355499814595495, 1}}, 
  TableHeadings -> {{\"Standard Mathematica\", \"Compile[WVM]\", \"Compile[C]\
\", \"External C++ via MathLink\"}, 
    {\"Time consumed\", \"Relative\"}}]\
\>", "\<\
                            Time consumed   Relative
Standard Mathematica        0.1874952       734.694

Compile[WVM]                0.011249712     44.08163

Compile[C]                  0.010520564     41.22449

External C++ via MathLink   0.0002552018    1\
\>"], "Text", "Input",
 CellChangeTimes->{{3.5086742375417805`*^9, 3.508674280040964*^9}}],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"Time consumed\"\>",
       HoldForm], 
      TagBox["\<\"Relative\"\>",
       HoldForm]},
     {
      TagBox["\<\"Standard Mathematica\"\>",
       HoldForm], "0.1874952`6.7245351474786625", 
      "734.6938775510204081719`6.629401392496409"},
     {
      TagBox["\<\"Compile[WVM]\"\>",
       HoldForm], "0.01124971200000000000004691387`7.979807652581967", 
      "44.0816326530612244924`7.246757858673671"},
     {
      TagBox["\<\"Compile[C]\"\>",
       HoldForm], "0.01052056399999999999995854243`7.950705270877666", 
      "41.2244897959183673491`7.2412276294251345"},
     {
      TagBox["\<\"External C++ via MathLink\"\>",
       HoldForm], "0.00025520179999999999998575491`7.3355499814595495", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{
      "Standard Mathematica", "Compile[WVM]", "Compile[C]", 
       "External C++ via MathLink"}, {
      "Time consumed", "Relative"}}]]]], "Output",
 CellChangeTimes->{3.508677854769203*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cleanup", "Section"],

Cell["\<\
Uninstall[installedLink];
CleanMathCodeFiles[Confirm \[Rule] False,CleanAllBut \[Rule] {}]\
\>", "Input"]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{1016, 666},
WindowMargins->{{16, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 20, 2007)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "\nModify the definitions below to change the default appearance of all \
cells in \na given style.  Make modifications to any definition using \
commands in the \nFormat menu.\n", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, ScriptMinSize -> 
          9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          ScriptMinSize -> 12, FontSize -> 16], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellBracketOptions -> {"Margins" -> {1, 1}, "Widths" -> {0, 5}}, 
          ScriptMinSize -> 8, FontSize -> 11], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, ScriptMinSize -> 
          7, FontSize -> 10, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "\nThe options defined for the style below will be used at the \
Notebook level.\n", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, 
          PageHeaderLines -> {True, True}, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False}, 
          CellFrameLabelMargins -> 6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 0}, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontSize -> 
             34, FontColor -> GrayLevel[1], Background -> RGBColor[0, 0, 1]], 
            
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 0}, FontSize -> 
             44], 
            Cell[
             StyleData["Title", "Condensed"], CellMargins -> {{0, 0}, {0, 0}},
              FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 0}, {0, 0}}, 
             FontSize -> 24, FontTracking -> "Plain", Background -> 
             GrayLevel[0]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], ShowCellBracket -> False, 
             CellMargins -> {{0, 0}, {0, 0}}, PageBreakBelow -> False, 
             LineSpacing -> {1, 3}, ParagraphIndent -> -96, CounterIncrements -> 
             "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 18, FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{0, 0}, {0, 0}}, LineSpacing -> {1, 6}, 
             ParagraphIndent -> -157, FontSize -> 30], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -78, 
             FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{0, 0}, {0, 0}}, ParagraphIndent -> -85, 
             FontSize -> 16, Background -> GrayLevel[0.6]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {30, 10}}, PageBreakBelow -> False, 
             CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{8, 10}, {40, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{9, 10}, {50, 10}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{6, 0}, {0, 1}}, CellDingbat -> 
             None, CellMargins -> {{12, Inherited}, {4, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> 6, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold", 
             FontColor -> RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{10, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, FontSize -> 14, FontTracking -> 
             "Plain", FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], 
             CellMargins -> {{12, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{11, 10}, {8, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {4, 40}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 12}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{29, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{22, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{21, 0}, {4, 20}}, FontSize -> 11]}, Open]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Text", FontFamily -> "Times"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {4, 4}},
              LineSpacing -> {1, 1}, ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{9, 0}, {4, 4}}, 
             ParagraphSpacing -> {0, 6}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 6}, 
             CounterIncrements -> "SmallText", FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{13, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {2, 2}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{9, 0}, {4, 4}}, FontSize -> 7]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "\nThe cells in this section define styles used for input and output \
to the \nkernel.  Be careful when modifying, renaming, or removing these \
styles, \nbecause the front end associates special meanings with these style \
names.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold", Background -> 
             RGBColor[1, 1, 0]], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{44, 0}, {6, 6}},
              Background -> GrayLevel[0.8]]}, Closed]], 
         Cell[
          StyleData["InlineInput"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, PageBreakWithin -> 
          False, GroupPageBreakWithin -> False, DefaultFormatType -> 
          DefaultInputFormatType, AutoItalicWords -> {}, FormatType -> 
          InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
          CounterIncrements -> "Input", FontWeight -> "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, CellEditDuplicate -> True, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{3, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Output", Background -> 
             RGBColor[1, 0.900008, 0.900008]], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{62, Inherited}, {12, 5}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{40, Inherited}, {4, 1}}], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{44, 0}, {6, 2}}, Background -> 
             GrayLevel[0.900008]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Message", StyleMenuListing -> 
             None, FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{50, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{62, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             CellMargins -> {{74, Inherited}, {Inherited, Inherited}}], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             CellMargins -> {{52, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {175, 175}], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             ImageSize -> {250, 250}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 11, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 8], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Author"], ShowCellBracket -> False, 
             CellMargins -> {{10, 4}, {2, 10}}, FontSize -> 16, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["Author", "Presentation"], 
             CellMargins -> {{12, 10}, {2, 12}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}, FontSize -> 20], 
            Cell[
             StyleData["Author", "Condensed"], 
             CellMargins -> {{8, 10}, {1, 4}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}, FontSize -> 12], 
            Cell[
             StyleData["Author", "Printout"], 
             CellMargins -> {{9, 0}, {4, 12}}, ParagraphSpacing -> {0, 6}, 
             FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Copyright"], ShowCellBracket -> False, 
             CellMargins -> {{10, 10}, {40, 2}}, FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Presentation"], 
             CellMargins -> {{12, 10}, {50, 2}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["Copyright", "Condensed"], 
             CellMargins -> {{8, 10}, {12, 1}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["Copyright", "Printout"], 
             CellMargins -> {{9, 0}, {72, 4}}, FontSize -> 7]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Example"], CellMargins -> {{12, 10}, {5, 12}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 12}, 
             CounterIncrements -> "Example", FontFamily -> "Times", 
             FontWeight -> "Bold"], 
            Cell[
             StyleData["Example", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 20}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Example", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["Example", "Printout"], 
             CellMargins -> {{9, 0}, {4, 10}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Definition"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Definition", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0.2, 0.700008, 0.700008]], 
            Cell[
             StyleData["Definition", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Definition", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Definition", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.6]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Theorem"], CellFrame -> {{3, 0}, {0, 0}}, 
             CellMargins -> {{52, 10}, {8, 8}}, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             ShowStringCharacters -> True, CounterIncrements -> "Theorem", 
             FontFamily -> "Helvetica", FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Theorem", "Presentation"], 
             CellMargins -> {{62, Inherited}, {5, 12}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["Theorem", "Condensed"], 
             CellMargins -> {{40, 10}, {1, 4}}], 
            Cell[
             StyleData["Theorem", "Printout"], 
             CellMargins -> {{44, 0}, {2, 6}}, Background -> GrayLevel[0.4]]},
            Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseMain"], CellFrame -> {{6, 0}, {0, 1}}, 
             CellMargins -> {{12, Inherited}, {4, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameColor -> RGBColor[0.571389, 0.19675, 0.570504], 
             CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 16, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["ExerciseMain", "Presentation"], 
             CellMargins -> {{18, 10}, {8, 32}}, LineSpacing -> {1, 2}, 
             FontSize -> 24, FontTracking -> "Condensed"], 
            Cell[
             StyleData["ExerciseMain", "Condensed"], 
             CellMargins -> {{8, Inherited}, {2, 12}}, FontSize -> 12], 
            Cell[
             StyleData["ExerciseMain", "Printout"], 
             CellMargins -> {{9, 0}, {2, 50}}, CellFrameColor -> 
             GrayLevel[0.500008], FontSize -> 14, FontTracking -> "Plain", 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Exercise"], CellDingbat -> "\[FilledDownTriangle]", 
             CellMargins -> {{23, Inherited}, {4, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Times", FontSize -> 13, FontWeight -> "Bold", FontColor -> 
             RGBColor[0.571389, 0.19675, 0.570504]], 
            Cell[
             StyleData["Exercise", "Presentation"], 
             CellMargins -> {{33, 10}, {8, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Exercise", "Condensed"], 
             CellMargins -> {{17, Inherited}, {2, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Exercise", "Printout"], 
             CellFrame -> {{0, 0}, {0.5, 0}}, CellDingbat -> None, 
             CellMargins -> {{9, 0}, {6, 20}}, FontSize -> 11, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ExerciseText"], CellMargins -> {{62, 10}, {5, 5}}, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "ExcersiceText", FontFamily -> "Times"], 
            Cell[
             StyleData["ExerciseText", "Presentation"], 
             CellMargins -> {{74, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["ExerciseText", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 2}}, LineSpacing -> {1, 1}, 
             ParagraphSpacing -> {0, 4}], 
            Cell[
             StyleData["ExerciseText", "Printout"], 
             CellMargins -> {{54, 0}, {4, 4}}, ParagraphSpacing -> {0, 6}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Itemize"], CellDingbat -> "\[FilledSmallCircle]", 
             CellMargins -> {{65, Inherited}, {8, 8}}, FontFamily -> "Times", 
             FontSize -> 13, FontWeight -> "Bold"], 
            Cell[
             StyleData["Itemize", "Presentation"], 
             CellMargins -> {{Inherited, 10}, {8, 12}}, LineSpacing -> {1, 0},
              FontSize -> 18], 
            Cell[
             StyleData["Itemize", "Condensed"], 
             CellMargins -> {{Inherited, Inherited}, {2, 12}}, FontSize -> 
             10], 
            Cell[
             StyleData["Itemize", "Printout"], 
             CellMargins -> {{Inherited, 0}, {4, 20}}, FontSize -> 11]}, 
           Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayCode"], CellFrame -> 2, 
             CellMargins -> {{52, 10}, {8, 8}}, CellHorizontalScrolling -> 
             True, PageBreakWithin -> True, 
             CellLabelMargins -> {{5, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, FormatType -> 
             InputForm, ShowStringCharacters -> True, NumberMarks -> True, 
             FontWeight -> "Bold", Background -> RGBColor[1, 1, 0]], 
            Cell[
             StyleData["DisplayCode", "Presentation"], 
             CellMargins -> {{62, Inherited}, {10, 10}}, 
             LineSpacing -> {1, 0}], 
            Cell[
             StyleData["DisplayCode", "Condensed"], 
             CellMargins -> {{40, 10}, {4, 4}}], 
            Cell[
             StyleData["DisplayCode", "Printout"], 
             CellMargins -> {{44, 0}, {6, 6}}, Background -> GrayLevel[0.8]]},
            Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], CellMargins -> {{62, 10}, {2, 10}}, 
             CellHorizontalScrolling -> True, ScriptLevel -> 0, 
             SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 18], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], CellMargins -> {{62, 10}, {2, 10}},
              AutoSpacing -> False, ScriptBaselineShifts -> {0.6, Automatic}, 
             ScriptLevel -> 1, SingleLetterItalics -> False, ZeroWidthTimes -> 
             True], 
            Cell[
             StyleData["ChemicalFormula", "Presentation"], 
             CellMargins -> {{74, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Condensed"], 
             CellMargins -> {{52, 10}, {2, 10}}, FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{54, 10}, {2, 10}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellMargins -> {{12, 10}, {Inherited, 6}}, 
             FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{13, 30}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {Inherited, 4}}, FontSize -> 9.5], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{9, 0}, {Inherited, 4}}, FontSize -> 9.5]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Automatic Numbering", "Section"], 
         Cell[
         "\nThe following styles are useful for numbered equations, figures, \
etc.  They \nautomatically give the cell a FrameLabel containing a reference \
to a \nparticular counter, and also increment that counter.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], 
             CellMargins -> {{62, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["NumberedEquation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, CounterIncrements -> 
             "NumberedEquation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Presentation"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Condensed"], 
             CellMargins -> {{52, 10}, {Inherited, Inherited}}], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigure"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Figure ", 
                   CounterBox["NumberedFigure"]}]], None}}, CounterIncrements -> 
             "NumberedFigure", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedFigure", "Presentation"]], 
            Cell[
             StyleData["NumberedFigure", "Condensed"]], 
            Cell[
             StyleData["NumberedFigure", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTable"], 
             CellMargins -> {{62, 145}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {
                Cell[
                 TextData[{"Table ", 
                   CounterBox["NumberedTable"]}]], None}}, TextAlignment -> 
             Center, CounterIncrements -> "NumberedTable", 
             FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedTable", "Presentation"]], 
            Cell[
             StyleData["NumberedTable", "Condensed"]], 
            Cell[
             StyleData["NumberedTable", "Printout"]]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 6],
          
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 9, 
          FontWeight -> "Bold"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "\nThe cells below define styles useful for making hypertext \
ButtonBoxes.  The \n\"Hyperlink\" style is for links within the same \
Notebook, or between \nNotebooks.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Condensed"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
         "\nThe following styles are for linking automatically to the on-line \
help \nsystem.\n", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Condensed"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Condensed"]], 
            Cell[
             StyleData["AddOnLink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Condensed"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[1, 0.4, 0], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]]}, Closed]]},
      Open]]}, Visible -> False, FrontEndVersion -> 
  "6.0 for Microsoft Windows (32-bit) (April 20, 2007)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 51, 0, 55, "Title"],
Cell[622, 23, 73, 2, 54, "Copyright"],
Cell[CellGroupData[{
Cell[720, 29, 31, 0, 54, "Section"],
Cell[754, 31, 337, 10, 25, "Text"],
Cell[1094, 43, 318, 12, 25, "Text"],
Cell[1415, 57, 225, 8, 25, "Text"],
Cell[1643, 67, 582, 15, 61, "Text"],
Cell[2228, 84, 958, 30, 61, "Text"],
Cell[3189, 116, 576, 14, 43, "Text"],
Cell[3768, 132, 104, 3, 25, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3909, 140, 33, 0, 54, "Section"],
Cell[CellGroupData[{
Cell[3967, 144, 47, 0, 44, "Subsection"],
Cell[4017, 146, 108, 3, 25, "Text"],
Cell[CellGroupData[{
Cell[4150, 153, 74, 1, 48, "Input"],
Cell[4227, 156, 448, 10, 23, "Print"]
}, Open  ]],
Cell[4690, 169, 66, 0, 25, "Text"],
Cell[4759, 171, 847, 23, 209, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5643, 199, 45, 0, 70, "Subsection"],
Cell[5691, 201, 155, 3, 70, "Text"],
Cell[5849, 206, 116, 3, 70, "Input"],
Cell[5968, 211, 68, 0, 70, "Text"],
Cell[6039, 213, 46, 0, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6134, 219, 50, 0, 70, "Section"],
Cell[6187, 221, 225, 4, 70, "Text"],
Cell[6415, 227, 498, 15, 70, "Input"],
Cell[CellGroupData[{
Cell[6938, 246, 38, 0, 70, "Subsection"],
Cell[6979, 248, 449, 8, 70, "Text"],
Cell[7431, 258, 688, 24, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8156, 287, 49, 0, 70, "Subsection"],
Cell[8208, 289, 984, 28, 70, "Text"],
Cell[9195, 319, 434, 10, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9678, 335, 53, 0, 70, "Section"],
Cell[9734, 337, 230, 4, 70, "Text"],
Cell[9967, 343, 102, 2, 70, "Input"],
Cell[CellGroupData[{
Cell[10094, 349, 38, 0, 70, "Subsection"],
Cell[10135, 351, 41, 0, 70, "Text"],
Cell[10179, 353, 292, 9, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10508, 367, 30, 0, 70, "Subsection"],
Cell[10541, 369, 54, 0, 70, "Text"],
Cell[10598, 371, 307, 6, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10942, 382, 28, 0, 70, "Subsection"],
Cell[10973, 384, 127, 4, 70, "Text"],
Cell[11103, 390, 810, 23, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11950, 418, 29, 0, 70, "Subsection"],
Cell[11982, 420, 678, 17, 70, "Text"],
Cell[12663, 439, 311, 9, 70, "Text"],
Cell[12977, 450, 305, 5, 70, "Text"],
Cell[13285, 457, 245, 11, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13567, 473, 31, 0, 70, "Subsection"],
Cell[13601, 475, 192, 6, 70, "Text"],
Cell[13796, 483, 730, 24, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14563, 512, 51, 0, 70, "Subsection"],
Cell[14617, 514, 46, 3, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14712, 523, 28, 0, 70, "Section"],
Cell[14743, 525, 420, 13, 70, "Text"],
Cell[CellGroupData[{
Cell[15188, 542, 97, 4, 70, "Subsection"],
Cell[15288, 548, 107, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[15420, 557, 118, 1, 70, "Input"],
Cell[15541, 560, 95, 1, 70, "Output"]
}, Open  ]],
Cell[15651, 564, 33, 0, 70, "Text"],
Cell[CellGroupData[{
Cell[15709, 568, 66, 1, 70, "Input"],
Cell[15778, 571, 89757, 1460, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[105584, 2037, 156, 7, 70, "Subsection"],
Cell[105743, 2046, 248, 11, 70, "Text"],
Cell[CellGroupData[{
Cell[106016, 2061, 5836, 140, 70, "Input"],
Cell[111855, 2203, 700, 12, 70, "Message"],
Cell[112558, 2217, 1463, 23, 70, "Print"],
Cell[114024, 2242, 1461, 23, 70, "Print"]
}, Open  ]],
Cell[115500, 2268, 96, 1, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115633, 2274, 78, 0, 70, "Subsection"],
Cell[115714, 2276, 152, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[115891, 2285, 30, 0, 70, "Input"],
Cell[115924, 2287, 32318, 893, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[148291, 3186, 55, 0, 70, "Subsection"],
Cell[148349, 3188, 47, 0, 70, "Text"],
Cell[CellGroupData[{
Cell[148421, 3192, 84, 1, 70, "Input"],
Cell[148508, 3195, 122, 1, 70, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[148679, 3202, 44, 0, 70, "Subsection"],
Cell[148726, 3204, 380, 10, 70, "Text"],
Cell[149109, 3216, 481, 12, 70, "Text"],
Cell[149593, 3230, 432, 14, 70, "Text"],
Cell[150028, 3246, 89, 2, 70, "Text"],
Cell[CellGroupData[{
Cell[150142, 3252, 82, 1, 70, "Input"],
Cell[150227, 3255, 3722, 167, 70, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[153998, 3428, 56, 0, 70, "Subsection"],
Cell[154057, 3430, 441, 13, 70, "Text"],
Cell[154501, 3445, 76, 2, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154614, 3452, 62, 0, 70, "Subsection"],
Cell[154679, 3454, 196, 6, 70, "Text"],
Cell[CellGroupData[{
Cell[154900, 3464, 116, 2, 70, "Input"],
Cell[155019, 3468, 240, 6, 70, "Print"],
Cell[155262, 3476, 230, 4, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[155541, 3486, 53, 0, 70, "Subsection"],
Cell[155597, 3488, 53, 0, 70, "Text"],
Cell[CellGroupData[{
Cell[155675, 3492, 393, 12, 70, "Input"],
Cell[156071, 3506, 118, 1, 70, "Output"]
}, Open  ]],
Cell[156204, 3510, 55, 0, 70, "Text"],
Cell[CellGroupData[{
Cell[156284, 3514, 66, 1, 70, "Input"],
Cell[156353, 3517, 89768, 1460, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[246170, 4983, 44, 0, 70, "Subsection"],
Cell[246217, 4985, 478, 14, 70, "Text"],
Cell[CellGroupData[{
Cell[246720, 5003, 1187, 31, 70, "Input"],
Cell[247910, 5036, 1759, 47, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[249706, 5088, 897, 21, 70, "Text"],
Cell[250606, 5111, 1765, 47, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[252432, 5165, 26, 0, 70, "Section"],
Cell[252461, 5167, 115, 3, 70, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

