(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     20990,        690]
NotebookOptionsPosition[     18469,        602]
NotebookOutlinePosition[     18834,        618]
CellTagsIndexPosition[     18791,        615]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Using MathCodeExport (",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6.0 and later)"
}], "Title",
 CellChangeTimes->{{3.4644256761484756`*^9, 3.464425684211182*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code developed using MathCode depends on MathCode to handle certain \
features, for example type declarations, automatic array allocation and array \
slice operators. Interpreted execution of such packages can be achieved \
outside MathCode by including the packages ",
 StyleBox["MathCodeExport.mx",
  FontWeight->"Bold"],
 " and ",
 StyleBox["matsyntax.m",
  FontWeight->"Bold"],
 " in the distribution and changing",
 StyleBox[" Needs[\"MathCode\"]",
  FontWeight->"Bold"],
 " into ",
 StyleBox["Get[\"MathCodeExport.mx\"];Get[\"matsyntax.m\"]",
  FontWeight->"Bold"],
 ".\nThis can be used to distribute MathCode-dependent applications and code \
to non-MathCode users.\nMathCode installation may already include the file ",
 StyleBox["System/MathCodeExport.mx",
  FontWeight->"Bold"],
 " for an older version of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". This file should ",
 StyleBox["not",
  FontWeight->"Bold"],
 " be used, because the ",
 StyleBox[".mx",
  FontWeight->"Bold"],
 " format is not compatible between different ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " versions, as well as between different hardware platforms.\n"
}], "Text",
 CellChangeTimes->{{3.461573361393369*^9, 3.461573434971494*^9}}],

Cell["\<\
This notebook explains 
1) how to create your own MathCodeExport.mx
2) how to use it
\
\>", "Text"],

Cell[BoxData[
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"$VersionNumber", "<", "6.0"}], ",", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Only Mathematica 6.0 and higher is supported. \>\"", 
     "]"}], ";", "Quit", ";"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.461564624421875*^9, 3.46156462559375*^9}, {
  3.4644256476944866`*^9, 3.4644256478976183`*^9}}],

Cell[CellGroupData[{

Cell["\<\

Creating MathCodeExport.mx and Copying matsyntax.m\
\>", "Section",
 CellChangeTimes->{{3.461573696565244*^9, 3.461573710612119*^9}}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<MathCode`\>\"", "]"}]], "Input"],

Cell["Set a directory not related to MathCode", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"$MCRoot", "<>", "\"\</Demos/UsingMathCodeExport\>\""}], 
  "]"}]], "Input"],

Cell[BoxData["\<\"d:\\\\b\\\\omath\\\\MathCode\\\\Demos\\\\\
UsingMathCodeExport\"\>"], "Output",
 CellChangeTimes->{3.464425900341715*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DumpSave", "[", 
  RowBox[{"\"\</tmp/MathCodeExport.mx\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "\"\<MathCode`\>\"", ",", "\"\<MathCodeCommands`\>\"", ",", 
     "\"\<MathCodeConv`\>\"", ",", "\"\<MathCodeConvSymb`\>\"", ",", 
     "\"\<MathCodeLanguage`\>\"", ",", " ", 
     "\"\<MathCodeLanguage`Private`\>\"", ",", "\"\<MathCode`Private`\>\"", 
     ",", "\"\<MCUtilities`\>\"", ",", " ", "\"\<SafeMathProg`\>\"", ",", 
     "\"\<SafeMathProg`Private`\>\""}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.460952722854711*^9, 3.4609527339799957`*^9}, {
   3.460952797153488*^9, 3.4609528057005816`*^9}, {3.4609529070313005`*^9, 
   3.460952912031429*^9}, 3.4609539201666117`*^9, {3.460954080936352*^9, 
   3.4609540842489367`*^9}, 3.461572623893369*^9, {3.461573653455869*^9, 
   3.461573657737119*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"MathCode`\"\>", ",", "\<\"MathCodeCommands`\"\>", 
   ",", "\<\"MathCodeConv`\"\>", ",", "\<\"MathCodeConvSymb`\"\>", 
   ",", "\<\"MathCodeLanguage`\"\>", ",", "\<\"MathCodeLanguage`Private`\"\>",
    ",", "\<\"MathCode`Private`\"\>", ",", "\<\"MCUtilities`\"\>", 
   ",", "\<\"SafeMathProg`\"\>", ",", "\<\"SafeMathProg`Private`\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4644259006229725`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FileNames", "[", 
      RowBox[{"\"\<matsyntax.m\>\"", ",", 
       RowBox[{"{", "\"\</tmp\>\"", "}"}]}], "]"}], "\[NotEqual]", 
     RowBox[{"{", "}"}]}], " ", ",", " ", 
    RowBox[{"DeleteFile", "[", "\"\</tmp/matsyntax.m\>\"", "]"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.461574568883537*^9, 3.4615745800094624`*^9}, {
  3.4615746792052145`*^9, 3.4615747003787794`*^9}, {3.4615747582400055`*^9, 
  3.4615748044289837`*^9}, {3.461574988480692*^9, 3.4615749964027696`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CopyFile", "[", 
    RowBox[{
     RowBox[{"$MCRoot", "<>", "\"\</System/matsyntax.m\>\""}], ",", 
     "\"\</tmp/matsyntax.m\>\""}], "]"}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.4615740209858303`*^9, 3.461574067733883*^9}, 
   3.4615750078718133`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"foo", "[", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{"mat", ",", "\[IndentingNewLine]", " ", 
      RowBox[{"p", "=", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mat", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "_"}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "p"}], ",", 
         RowBox[{"p", ";;", "p"}]}], "]"}], "]"}], "=", "44"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "p"}], ",", 
         RowBox[{"p", ";;", "p"}]}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"_", "|", "p"}], ",", 
         RowBox[{";;", "p"}]}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"_", "|", "p"}], ",", 
         RowBox[{";;", "p"}]}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"_", "|", "p"}], ",", 
          RowBox[{";;", "p"}]}], "]"}], "]"}], "*", "10"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "_"}], ",", 
         RowBox[{"p", ";;"}]}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "_"}], ",", 
         RowBox[{"p", ";;"}]}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"p", "|", "_"}], ",", 
          RowBox[{"p", ";;"}]}], "]"}], "]"}], "*", "5"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", ";;"}], "]"}], "]"}], "/", "50"}], "]"}], ";", 
     "\[IndentingNewLine]", "mat"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.46156477253125*^9, 3.461564885640625*^9}, {
   3.46156497190625*^9, 3.46156499621875*^9}, {3.461565033546875*^9, 
   3.461565034875*^9}, {3.461565226453125*^9, 3.461565258390625*^9}, {
   3.461570858502744*^9, 3.461570866049619*^9}, {3.461570908315244*^9, 
   3.461571013065244*^9}, {3.461571096112119*^9, 3.461571171533994*^9}, {
   3.461571526721494*^9, 3.461571529846494*^9}, 3.461571632315244*^9, {
   3.461571687252744*^9, 3.461571699596494*^9}, {3.461573777190244*^9, 
   3.461573778096494*^9}, {3.464425594739667*^9, 3.464425619568587*^9}}],

Cell[BoxData[
 RowBox[{"Declare", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"foo", "[", "]"}], "\[Rule]", 
    RowBox[{"Real", " ", "[", 
     RowBox[{"_", ",", "_"}], "]"}]}], " ", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Real", " ", "[", 
      RowBox[{"_", ",", "_"}], "]"}], " ", ",", "Integer"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.461571485705869*^9, 3.461571523955869*^9}, {
   3.461571600596494*^9, 3.461571602408994*^9}, {3.461571750112119*^9, 
   3.461571774893369*^9}, 3.461574295111106*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mm", "=", 
  RowBox[{"foo", "[", "]"}]}]], "Input",
 CellChangeTimes->{
  3.461573762018369*^9, {3.461573792846494*^9, 3.46157381427814*^9}, {
   3.46157385606996*^9, 3.4615738862607594`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.4644259007010994`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "44", "}"}], "}"}]], "Print",
 CellChangeTimes->{3.4644259007167244`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "44"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.4644259007479753`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "440", "}"}], "}"}]], "Print",
 CellChangeTimes->{3.464425900763601*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "5"], ",", 
     FractionBox["2", "5"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "5"], ",", "44"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.4644259007948513`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"10", ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", "2200"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4644259008104773`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BuildCode", "[", "]"}]], "Input",
 CellChangeTimes->{
  3.461573762018369*^9, {3.461573792846494*^9, 3.46157381427814*^9}}],

Cell[BoxData["\<\"Successful compilation to C++: 2 function(s)\"\>"], "Print",
 CellChangeTimes->{3.4644259032167883`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InstallCode", "[", "]"}]], "Input",
 CellChangeTimes->{{3.461573820453886*^9, 3.4615738267078056`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Global\"\>", "\[InvisibleSpace]", "\<\" is installed.\"\>"}],
  SequenceForm["Global", " is installed."],
  Editable->False]], "Print",
 CellChangeTimes->{3.46442590895131*^9}],

Cell[BoxData[
 RowBox[{"LinkObject", "[", 
  RowBox[{"\<\"\\\".\\\\Globalml.exe\\\"\"\>", ",", "22", ",", "7"}], 
  "]"}]], "Output",
 CellChangeTimes->{3.464425908966936*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mc", "=", 
  RowBox[{"foo", "[", "]"}]}]], "Input",
 CellChangeTimes->{{3.461573820453886*^9, 3.461573852411417*^9}, {
  3.461573888762327*^9, 3.461573890325807*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"10.`", ",", "20.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30.`", ",", "2200.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4644259089981866`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mm", "\[Equal]", "mc"}]], "Input",
 CellChangeTimes->{{3.4615738370580435`*^9, 3.461573843077441*^9}, {
   3.4615738761450434`*^9, 3.461573897439641*^9}, 3.461574329790969*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.464425909029437*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"UninstallCode", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4615738370580435`*^9, 3.461573843077441*^9}, {
   3.4615738761450434`*^9, 3.461573897439641*^9}, 3.461574329790969*^9}],

Cell[BoxData["\<\"\\\".\\\\Globalml.exe\\\"\"\>"], "Output",
 CellChangeTimes->{3.464425909060688*^9}]
}, Open  ]],

Cell[BoxData["Quit"], "Input",
 CellChangeTimes->{{3.461573820453886*^9, 3.46157383066341*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using MathCodeExport.mx", "Section"],

Cell[BoxData[
 RowBox[{"Get", "[", "\"\<C:\\\\tmp\\\\matsyntax.m\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4609562435385885`*^9, 3.460956252898203*^9}, 
   3.460956374151307*^9, 3.461561569984375*^9, 3.46156268571875*^9, 
   3.461572779408994*^9}],

Cell[BoxData[
 RowBox[{"Get", "[", "\"\<C:\\\\tmp\\\\MathCodeExport.mx\>\"", "]"}]], "Input",\

 CellChangeTimes->{{3.461572673174619*^9, 3.461572677737119*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"foo", "[", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{"mat", ",", "\[IndentingNewLine]", " ", 
      RowBox[{"p", "=", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"mat", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "_"}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "p"}], ",", 
         RowBox[{"p", ";;", "p"}]}], "]"}], "]"}], "=", "44"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "p"}], ",", 
         RowBox[{"p", ";;", "p"}]}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"_", "|", "p"}], ",", 
         RowBox[{";;", "p"}]}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"_", "|", "p"}], ",", 
         RowBox[{";;", "p"}]}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"_", "|", "p"}], ",", 
          RowBox[{";;", "p"}]}], "]"}], "]"}], "*", "10"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "_"}], ",", 
         RowBox[{"p", ";;"}]}], "]"}], "]"}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"p", "|", "_"}], ",", 
         RowBox[{"p", ";;"}]}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"p", "|", "_"}], ",", 
          RowBox[{"p", ";;"}]}], "]"}], "]"}], "*", "5"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", ";;"}], "]"}], "]"}], "/", "50"}], "]"}], ";", 
     "\[IndentingNewLine]", "mat"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.46156477253125*^9, 3.461564885640625*^9}, {
   3.46156497190625*^9, 3.46156499621875*^9}, {3.461565033546875*^9, 
   3.461565034875*^9}, {3.461565226453125*^9, 3.461565258390625*^9}, {
   3.461570858502744*^9, 3.461570866049619*^9}, {3.461570908315244*^9, 
   3.461571013065244*^9}, {3.461571096112119*^9, 3.461571171533994*^9}, {
   3.461571526721494*^9, 3.461571529846494*^9}, 3.461571632315244*^9, {
   3.461571687252744*^9, 3.461571699596494*^9}, {3.461575103311756*^9, 
   3.461575104264906*^9}, {3.464425552082052*^9, 3.4644255827861595`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Declare", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"foo", "[", "]"}], "\[Rule]", 
     RowBox[{"Real", " ", "[", 
      RowBox[{"_", ",", "_"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Real", " ", "[", 
       RowBox[{"_", ",", "_"}], "]"}], " ", ",", "Integer"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.461571485705869*^9, 3.461571523955869*^9}, {
  3.461571600596494*^9, 3.461571602408994*^9}, {3.461571750112119*^9, 
  3.461571774893369*^9}, {3.4615744196367455`*^9, 3.4615744302470036`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"foo", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4615648454375*^9, 3.461564853765625*^9}, {
   3.461571019612119*^9, 3.461571021987119*^9}, 3.461571537768369*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.46442591734215*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "44", "}"}], "}"}]], "Print",
 CellChangeTimes->{3.4644259173577757`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "44"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.4644259173890266`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "440", "}"}], "}"}]], "Print",
 CellChangeTimes->{3.4644259174046516`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "5"], ",", 
     FractionBox["2", "5"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "5"], ",", "44"}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.464425917420277*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"10", ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", "2200"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4644259174671535`*^9}]
}, Open  ]],

Cell[BoxData["Quit"], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{981, 941},
WindowMargins->{{125, Automatic}, {-25, Automatic}},
ShowSelection->True,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 20, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 191, 6, 83, "Title"],
Cell[784, 31, 1315, 37, 155, "Text"],
Cell[2102, 70, 109, 5, 83, "Text"],
Cell[2214, 77, 365, 9, 31, "Input"],
Cell[CellGroupData[{
Cell[2604, 90, 144, 4, 97, "Section"],
Cell[2751, 96, 74, 1, 31, "Input"],
Cell[2828, 99, 55, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[2908, 103, 131, 3, 31, "Input"],
Cell[3042, 108, 139, 2, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3218, 115, 838, 15, 72, "Input"],
Cell[4059, 132, 447, 8, 50, "Output"]
}, Open  ]],
Cell[4521, 143, 574, 13, 31, "Input"],
Cell[5098, 158, 328, 9, 52, "Input"],
Cell[5429, 169, 3180, 90, 292, "Input"],
Cell[8612, 261, 526, 14, 31, "Input"],
Cell[CellGroupData[{
Cell[9163, 279, 216, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[9404, 288, 214, 7, 23, "Print"],
Cell[9621, 297, 117, 3, 23, "Print"],
Cell[9741, 302, 215, 7, 23, "Print"],
Cell[9959, 311, 116, 3, 23, "Print"],
Cell[10078, 316, 287, 10, 38, "Print"]
}, Open  ]],
Cell[10380, 329, 221, 7, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10638, 341, 147, 3, 31, "Input"],
Cell[10788, 346, 122, 1, 23, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10947, 352, 127, 2, 31, "Input"],
Cell[11077, 356, 225, 5, 23, "Print"],
Cell[11305, 363, 175, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11517, 372, 190, 4, 31, "Input"],
Cell[11710, 378, 229, 7, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11976, 390, 200, 3, 31, "Input"],
Cell[12179, 395, 73, 1, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12289, 401, 203, 3, 31, "Input"],
Cell[12495, 406, 102, 1, 30, "Output"]
}, Open  ]],
Cell[12612, 410, 95, 1, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12744, 416, 42, 0, 71, "Section"],
Cell[12789, 418, 250, 4, 31, "Input"],
Cell[13042, 424, 161, 3, 31, "Input"],
Cell[13206, 429, 3182, 90, 292, "Input"],
Cell[16391, 521, 574, 15, 31, "Input"],
Cell[CellGroupData[{
Cell[16990, 540, 187, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[17202, 547, 211, 7, 23, "Print"],
Cell[17416, 556, 117, 3, 23, "Print"],
Cell[17536, 561, 215, 7, 23, "Print"],
Cell[17754, 570, 118, 3, 23, "Print"],
Cell[17875, 575, 285, 10, 38, "Print"]
}, Open  ]],
Cell[18175, 588, 221, 7, 30, "Output"]
}, Open  ]],
Cell[18411, 598, 30, 0, 31, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
